#
#
# DO NOT EDIT THIS FILE, IT'S AUTOGENERATED FROM XS MODULES AND WILL BE UPDATED AUTOMATICALLY
#
#
package B {
sub CLONE;
sub address;
sub amagic_generation;
sub begin_av;
sub cast_I32;
sub cchar;
sub check_av;
sub comppadlist;
sub cstring;
sub curstash;
sub defstash;
sub diehook;
sub dowarn;
sub end_av;
sub formfeed;
sub hash;
sub inc_gv;
sub init_av;
sub main_cv;
sub main_root;
sub main_start;
sub minus_c;
sub opnumber;
sub perlstring;
sub ppname;
sub regex_padav;
sub save_BEGINs;
sub sub_generation;
sub sv_no;
sub sv_undef;
sub sv_yes;
sub svref_2object;
sub threadsv_names;
sub unitcheck_av;
sub walkoptree;
sub walkoptree_debug;
sub warnhook;
}
package B::AV {
sub ARRAY;
sub ARRAYelt;
sub FILL;
sub MAX;
}
package B::BINOP {
sub last;
}
package B::BM {
sub PREVIOUS;
sub RARE;
sub TABLE;
sub USEFUL;
}
package B::COP {
sub arybase;
sub cop_seq;
sub file;
sub filegv;
sub hints;
sub hints_hash;
sub io;
sub label;
sub line;
sub stash;
sub stashoff;
sub stashpv;
sub warnings;
}
package B::CV {
sub CONST;
sub CvFLAGS;
sub DEPTH;
sub FILE;
sub GV;
sub HSCXT;
sub NAME_HEK;
sub OUTSIDE;
sub OUTSIDE_SEQ;
sub PADLIST;
sub ROOT;
sub START;
sub STASH;
sub XSUB;
sub XSUBANY;
sub const_sv;
}
package B::Deparse {
sub main_cv;
sub main_root;
sub main_start;
sub opnumber;
sub perlstring;
sub svref_2object;
}
package B::FM {
sub LINES;
}
package B::GV {
sub AV;
sub CV;
sub CVGEN;
sub EGV;
sub FILE;
sub FILEGV;
sub FORM;
sub GP;
sub GPFLAGS;
sub GvFLAGS;
sub GvREFCNT;
sub HV;
sub IO;
sub LINE;
sub NAME;
sub STASH;
sub SV;
sub isGV_with_GP;
sub is_empty;
}
package B::HE {
sub HASH;
sub SVKEY_force;
sub VAL;
}
package B::HV {
sub ARRAY;
sub FILL;
sub KEYS;
sub MAX;
sub NAME;
sub RITER;
}
package B::INVLIST {
sub array_len;
sub get_invlist_array;
sub is_offset;
sub prev_index;
}
package B::IO {
sub BOTTOM_GV;
sub BOTTOM_NAME;
sub FMT_GV;
sub FMT_NAME;
sub IoFLAGS;
sub IoTYPE;
sub IsSTD;
sub LINES;
sub LINES_LEFT;
sub PAGE;
sub PAGE_LEN;
sub TOP_GV;
sub TOP_NAME;
}
package B::IV {
sub IV;
sub IVX;
sub RV;
sub UVX;
sub needs64bits;
sub packiv;
}
package B::LISTOP {
sub children;
}
package B::LOGOP {
sub other;
}
package B::LOOP {
sub lastop;
sub nextop;
sub redoop;
}
package B::MAGIC {
sub FLAGS;
sub LENGTH;
sub MOREMAGIC;
sub OBJ;
sub PRIVATE;
sub PTR;
sub REGEX;
sub TYPE;
sub precomp;
}
package B::METHOP {
sub first;
sub meth_sv;
sub rclass;
}
package B::NV {
sub NV;
sub NVX;
}
package B::OP {
sub desc;
sub flags;
sub folded;
sub moresib;
sub name;
sub next;
sub oplist;
sub opt;
sub parent;
sub ppaddr;
sub private;
sub savefree;
sub sibling;
sub size;
sub slabbed;
sub spare;
sub static;
sub targ;
sub type;
}
package B::PADLIST {
sub ARRAY;
sub ARRAYelt;
sub MAX;
sub NAMES;
sub REFCNT;
sub id;
sub outid;
}
package B::PADNAME {
sub COP_SEQ_RANGE_HIGH;
sub COP_SEQ_RANGE_LOW;
sub FLAGS;
sub GEN;
sub IsUndef;
sub LEN;
sub OURSTASH;
sub PARENT_FAKELEX_FLAGS;
sub PARENT_PAD_INDEX;
sub PROTOCV;
sub PV;
sub PVX;
sub REFCNT;
sub SvSTASH;
sub TYPE;
}
package B::PADNAMELIST {
sub ARRAY;
sub ARRAYelt;
sub MAX;
sub REFCNT;
}
package B::PADOP {
sub gv;
sub padix;
sub sv;
}
package B::PMOP {
sub code_list;
sub pmflags;
sub pmoffset;
sub pmregexp;
sub pmreplroot;
sub pmreplstart;
sub pmstash;
sub pmstashpv;
sub precomp;
sub reflags;
}
package B::PV {
sub CUR;
sub LEN;
sub PV;
sub PVBM;
sub PVX;
sub RV;
sub as_string;
}
package B::PVLV {
sub TARG;
sub TARGLEN;
sub TARGOFF;
sub TYPE;
}
package B::PVMG {
sub MAGIC;
sub SvSTASH;
}
package B::PVOP {
sub pv;
}
package B::REGEXP {
sub REGEX;
sub compflags;
sub precomp;
sub qr_anoncv;
}
package B::RHE {
sub HASH;
}
package B::SV {
sub FLAGS;
sub IsBOOL;
sub MAGICAL;
sub POK;
sub REFCNT;
sub ROK;
sub SvTYPE;
sub TRUE;
sub TRUE_nomg;
sub object_2svref;
}
package B::SVOP {
sub gv;
sub sv;
}
package B::UNOP {
sub first;
}
package B::UNOP_AUX {
sub aux_list;
sub string;
}
package BSD::Resource {
sub _find_prio($$) ;
sub _find_rlimit($$) ;
sub _g;
sub _get_prios;
sub _get_rlimits;
sub _getpriority;
sub _getrlimit;
sub _getrusage;
sub _setpriority;
sub _setrlimit;
sub constant;
sub get_prios() ;
sub get_rlimits() ;
sub getpriority(;$$) ;
sub getrlimit($) ;
sub getrusage(;$) ;
sub hard;
sub idrss;
sub inblock;
sub isrss;
sub ixrss;
sub majflt;
sub maxrss;
sub minflt;
sub msgrcv;
sub msgsnd;
sub nivcsw;
sub nsignals;
sub nswap;
sub nvcsw;
sub oublock;
sub setpriority(;$$$) ;
sub setrlimit($$$) ;
sub soft;
sub stime;
sub times;
sub utime;
}
package CSS::Minifier::XS {
sub minify;
}
package Carp {
sub _maybe_isa;
sub downgrade;
sub is_utf8;
}
package Class::Load {
sub is_class_loaded;
}
package Class::Load::XS {
sub is_class_loaded;
}
package Class::MOP {
sub blessed($) ;
sub check_package_cache_flag($) ;
sub get_code_info($) ;
sub isweak($) ;
sub weaken($) ;
}
package Class::MOP::Attribute {
sub associated_class;
sub associated_methods;
sub blessed($) ;
sub weaken($) ;
}
package Class::MOP::Class {
sub all(&@) ;
sub blessed($) ;
sub constructor_class;
sub constructor_name;
sub destructor_class;
sub immutable_trait;
sub instance_metaclass;
sub set_subname;
}
package Class::MOP::Instance {
sub associated_metaclass;
sub blessed($) ;
sub isweak($) ;
sub slot_hash;
sub slots;
sub weaken($) ;
}
package Class::MOP::Method {
sub blessed($) ;
sub body;
sub is_stub;
sub name;
sub package_name;
sub reftype($) ;
sub weaken($) ;
}
package Class::MOP::Method::Accessor {
sub blessed($) ;
sub weaken($) ;
}
package Class::MOP::Method::Constructor {
sub blessed($) ;
sub weaken($) ;
}
package Class::MOP::Method::Generated {
sub definition_context;
sub is_inline;
}
package Class::MOP::Method::Inlined {
sub _expected_method_class;
sub refaddr($) ;
}
package Class::MOP::Method::Meta {
sub blessed($) ;
sub weaken($) ;
}
package Class::MOP::Method::Wrapped {
sub blessed($) ;
sub set_subname;
}
package Class::MOP::Mixin {
sub blessed($) ;
}
package Class::MOP::Mixin::AttributeCore {
sub accessor;
sub blessed($) ;
sub builder;
sub clearer;
sub definition_context;
sub init_arg;
sub initializer;
sub insertion_order;
sub name;
sub predicate;
sub reader;
sub writer;
}
package Class::MOP::Mixin::HasAttributes {
sub _attribute_map;
sub attribute_metaclass;
sub blessed($) ;
}
package Class::MOP::Mixin::HasMethods {
sub _method_map;
sub blessed($) ;
sub method_metaclass;
sub reftype($) ;
sub set_subname;
sub wrapped_method_metaclass;
}
package Class::MOP::Mixin::HasOverloads {
sub blessed($) ;
}
package Class::MOP::Object {
sub blessed($) ;
}
package Class::MOP::Overload {
sub blessed($) ;
sub weaken($) ;
}
package Class::MOP::Package {
sub blessed($) ;
sub name;
sub weaken($) ;
}
package Clone {
sub clone($;$) ;
}
package Compress::Raw::Bunzip2 {
sub DESTROY;
sub DispStream;
sub bzinflate;
sub compressedBytes;
sub inflateCount;
sub new;
sub status;
sub total_in_lo32;
sub total_out_lo32;
sub uncompressedBytes;
}
package Compress::Raw::Bzip2 {
sub DESTROY;
sub DispStream;
sub bzclose;
sub bzdeflate;
sub bzflush;
sub bzlibversion;
sub compressedBytes;
sub constant;
sub new;
sub total_in_lo32;
sub total_out_lo32;
sub uncompressedBytes;
}
package Compress::Raw::Zlib {
sub DEF_WBITS;
sub OS_CODE;
sub ZLIBNG_VERNUM;
sub ZLIBNG_VERSION;
sub ZLIBNG_VER_MAJOR;
sub ZLIBNG_VER_MINOR;
sub ZLIBNG_VER_MODIFIED;
sub ZLIBNG_VER_REVISION;
sub ZLIBNG_VER_STATUS;
sub ZLIB_VERNUM;
sub ZLIB_VERSION;
sub Z_ASCII;
sub Z_BEST_COMPRESSION;
sub Z_BEST_SPEED;
sub Z_BINARY;
sub Z_BLOCK;
sub Z_BUF_ERROR;
sub Z_DATA_ERROR;
sub Z_ERRNO;
sub Z_FILTERED;
sub Z_FINISH;
sub Z_FIXED;
sub Z_FULL_FLUSH;
sub Z_HUFFMAN_ONLY;
sub Z_MEM_ERROR;
sub Z_NEED_DICT;
sub Z_NO_COMPRESSION;
sub Z_NO_FLUSH;
sub Z_NULL;
sub Z_OK;
sub Z_PARTIAL_FLUSH;
sub Z_RLE;
sub Z_STREAM_END;
sub Z_STREAM_ERROR;
sub Z_SYNC_FLUSH;
sub Z_TREES;
sub Z_UNKNOWN;
sub Z_VERSION_ERROR;
sub _deflateInit;
sub _inflateInit;
sub _inflateScanInit;
sub adler32;
sub adler32_combine;
sub constant;
sub crc32;
sub crc32_combine;
sub is_zlib_native;
sub is_zlibng;
sub is_zlibng_compat;
sub is_zlibng_native;
sub zlibCompileFlags;
sub zlib_version;
sub zlibng_version;
}
package Compress::Raw::Zlib::deflateStream {
sub DESTROY;
sub DispStream;
sub _deflateParams;
sub adler32;
sub compressedBytes;
sub crc32;
sub deflate;
sub deflateReset;
sub deflateTune;
sub dict_adler;
sub flush;
sub get_Bufsize;
sub get_Level;
sub get_Strategy;
sub msg;
sub status;
sub total_in;
sub total_out;
sub uncompressedBytes;
}
package Compress::Raw::Zlib::inflateScanStream {
sub DESTROY;
sub DispStream;
sub _createDeflateStream;
sub adler32;
sub compressedBytes;
sub crc32;
sub getEndOffset;
sub getLastBlockOffset;
sub getLastBufferOffset;
sub inflateCount;
sub inflateReset;
sub resetLastBlockByte;
sub scan;
sub status;
sub uncompressedBytes;
}
package Compress::Raw::Zlib::inflateStream {
sub DESTROY;
sub DispStream;
sub adler32;
sub compressedBytes;
sub crc32;
sub dict_adler;
sub get_Bufsize;
sub inflate;
sub inflateCount;
sub inflateReset;
sub inflateSync;
sub msg;
sub set_Append;
sub status;
sub total_in;
sub total_out;
sub uncompressedBytes;
}
package Config {
sub AUTOLOAD;
}
package Cpanel::JSON::XS {
sub CLONE;
sub DESTROY;
sub _from_json($;$$) ;
sub _to_json($;$) ;
sub allow_barekey;
sub allow_bignum;
sub allow_blessed;
sub allow_dupkeys;
sub allow_nonref;
sub allow_singlequote;
sub allow_stringify;
sub allow_tags;
sub allow_unknown;
sub ascii;
sub binary;
sub canonical;
sub convert_blessed;
sub decode;
sub decode_json($;$$) ;
sub decode_prefix;
sub dupkeys_as_arrayref;
sub encode;
sub encode_json($;$) ;
sub escape_slash;
sub filter_json_object;
sub filter_json_single_key_object;
sub get_allow_barekey;
sub get_allow_bignum;
sub get_allow_blessed;
sub get_allow_dupkeys;
sub get_allow_nonref;
sub get_allow_singlequote;
sub get_allow_stringify;
sub get_allow_tags;
sub get_allow_unknown;
sub get_ascii;
sub get_binary;
sub get_canonical;
sub get_convert_blessed;
sub get_dupkeys_as_arrayref;
sub get_escape_slash;
sub get_indent;
sub get_indent_length;
sub get_latin1;
sub get_max_depth;
sub get_max_size;
sub get_relaxed;
sub get_require_types;
sub get_shrink;
sub get_space_after;
sub get_space_before;
sub get_stringify_infnan;
sub get_type_all_string;
sub get_unblessed_bool;
sub get_utf8;
sub incr_parse;
sub incr_reset;
sub incr_skip;
sub indent;
sub indent_length;
sub latin1;
sub max_depth;
sub max_size;
sub new;
sub pretty;
sub relaxed;
sub require_types;
sub shrink;
sub sort_by;
sub space_after;
sub space_before;
sub stringify_infnan;
sub type_all_string;
sub unblessed_bool;
sub utf8;
}
package Crypt::AuthEnc::CCM {
sub DESTROY;
sub ccm_decrypt_verify;
sub ccm_encrypt_authenticate;
sub clone;
sub decrypt_add;
sub decrypt_done;
sub encrypt_add;
sub encrypt_done;
sub new;
}
package Crypt::AuthEnc::ChaCha20Poly1305 {
sub DESTROY;
sub adata_add;
sub chacha20poly1305_decrypt_verify;
sub chacha20poly1305_encrypt_authenticate;
sub clone;
sub decrypt_add;
sub decrypt_done;
sub encrypt_add;
sub encrypt_done;
sub new;
sub set_iv;
sub set_iv_rfc7905;
}
package Crypt::AuthEnc::EAX {
sub DESTROY;
sub adata_add;
sub clone;
sub decrypt_add;
sub decrypt_done;
sub eax_decrypt_verify;
sub eax_encrypt_authenticate;
sub encrypt_add;
sub encrypt_done;
sub new;
}
package Crypt::AuthEnc::GCM {
sub DESTROY;
sub adata_add;
sub clone;
sub decrypt_add;
sub decrypt_done;
sub encrypt_add;
sub encrypt_done;
sub gcm_decrypt_verify;
sub gcm_encrypt_authenticate;
sub iv_add;
sub new;
sub reset;
}
package Crypt::AuthEnc::OCB {
sub DESTROY;
sub adata_add;
sub clone;
sub decrypt_add;
sub decrypt_done;
sub decrypt_last;
sub encrypt_add;
sub encrypt_done;
sub encrypt_last;
sub new;
sub ocb_decrypt_verify;
sub ocb_encrypt_authenticate;
}
package Crypt::Checksum::Adler32 {
sub DESTROY;
sub add;
sub adler32_data;
sub adler32_data_hex;
sub adler32_data_int;
sub clone;
sub digest;
sub hexdigest;
sub intdigest;
sub new;
sub reset;
}
package Crypt::Checksum::CRC32 {
sub DESTROY;
sub add;
sub clone;
sub crc32_data;
sub crc32_data_hex;
sub crc32_data_int;
sub digest;
sub hexdigest;
sub intdigest;
sub new;
sub reset;
}
package Crypt::Cipher {
sub DESTROY;
sub blocksize;
sub decrypt;
sub default_rounds;
sub encrypt;
sub max_keysize;
sub min_keysize;
sub new;
}
package Crypt::Digest {
sub DESTROY;
sub add;
sub b64digest;
sub b64udigest;
sub clone;
sub digest;
sub digest_data;
sub digest_data_b64;
sub digest_data_b64u;
sub digest_data_hex;
sub hashsize;
sub hexdigest;
sub new;
sub reset;
}
package Crypt::Digest::SHAKE {
sub DESTROY;
sub add;
sub clone;
sub done;
sub new;
sub reset;
}
package Crypt::KeyDerivation {
sub hkdf;
sub hkdf_expand;
sub hkdf_extract;
sub pbkdf1;
sub pbkdf2;
}
package Crypt::Mac::BLAKE2b {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub blake2b;
sub blake2b_b64;
sub blake2b_b64u;
sub blake2b_hex;
sub clone;
sub hexmac;
sub mac;
sub new;
}
package Crypt::Mac::BLAKE2s {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub blake2s;
sub blake2s_b64;
sub blake2s_b64u;
sub blake2s_hex;
sub clone;
sub hexmac;
sub mac;
sub new;
}
package Crypt::Mac::F9 {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub clone;
sub f9;
sub f9_b64;
sub f9_b64u;
sub f9_hex;
sub hexmac;
sub mac;
sub new;
}
package Crypt::Mac::HMAC {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub clone;
sub hexmac;
sub hmac;
sub hmac_b64;
sub hmac_b64u;
sub hmac_hex;
sub mac;
sub new;
}
package Crypt::Mac::OMAC {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub clone;
sub hexmac;
sub mac;
sub new;
sub omac;
sub omac_b64;
sub omac_b64u;
sub omac_hex;
}
package Crypt::Mac::PMAC {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub clone;
sub hexmac;
sub mac;
sub new;
sub pmac;
sub pmac_b64;
sub pmac_b64u;
sub pmac_hex;
}
package Crypt::Mac::Pelican {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub clone;
sub hexmac;
sub mac;
sub new;
sub pelican;
sub pelican_b64;
sub pelican_b64u;
sub pelican_hex;
}
package Crypt::Mac::Poly1305 {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub clone;
sub hexmac;
sub mac;
sub new;
sub poly1305;
sub poly1305_b64;
sub poly1305_b64u;
sub poly1305_hex;
}
package Crypt::Mac::XCBC {
sub DESTROY;
sub add;
sub b64mac;
sub b64umac;
sub clone;
sub hexmac;
sub mac;
sub new;
sub xcbc;
sub xcbc_b64;
sub xcbc_b64u;
sub xcbc_hex;
}
package Crypt::Misc {
sub _bin_to_radix;
sub _radix_to_bin;
sub decode_b32b;
sub decode_b32c;
sub decode_b32r;
sub decode_b32z;
sub decode_b64;
sub decode_b64u;
sub digest_data;
sub encode_b32b;
sub encode_b32c;
sub encode_b32r;
sub encode_b32z;
sub encode_b64;
sub encode_b64u;
sub increment_octets_be;
sub increment_octets_le;
}
package Crypt::Mode::CBC {
sub DESTROY;
sub add;
sub finish;
sub new;
sub start_decrypt;
sub start_encrypt;
}
package Crypt::Mode::CFB {
sub DESTROY;
sub add;
sub finish;
sub new;
sub start_decrypt;
sub start_encrypt;
}
package Crypt::Mode::CTR {
sub DESTROY;
sub add;
sub finish;
sub new;
sub start_decrypt;
sub start_encrypt;
}
package Crypt::Mode::ECB {
sub DESTROY;
sub add;
sub finish;
sub new;
sub start_decrypt;
sub start_encrypt;
}
package Crypt::Mode::OFB {
sub DESTROY;
sub add;
sub finish;
sub new;
sub start_decrypt;
sub start_encrypt;
}
package Crypt::PK::DH {
sub DESTROY;
sub _generate_key_dhparam;
sub _generate_key_gp;
sub _generate_key_size;
sub _import;
sub _import_raw;
sub _new;
sub export_key;
sub export_key_raw;
sub is_private;
sub key2hash;
sub params2hash;
sub shared_secret;
sub size;
}
package Crypt::PK::DSA {
sub DESTROY;
sub _generate_key_dsaparam;
sub _generate_key_pqg_hex;
sub _generate_key_size;
sub _import;
sub _import_hex;
sub _import_openssh;
sub _import_pem;
sub _import_pkcs8;
sub _new;
sub decrypt;
sub encrypt;
sub export_key_der;
sub is_private;
sub key2hash;
sub sign_hash;
sub sign_message;
sub size;
sub size_q;
sub verify_hash;
sub verify_message;
}
package Crypt::PK::ECC {
sub DESTROY;
sub _import;
sub _import_old;
sub _import_openssh;
sub _import_pem;
sub _import_pkcs8;
sub _import_x509;
sub _new;
sub decrypt;
sub encrypt;
sub export_key_der;
sub export_key_raw;
sub generate_key;
sub import_key_raw;
sub is_private;
sub key2hash;
sub recovery_pub;
sub recovery_pub_eth;
sub recovery_pub_rfc7518;
sub shared_secret;
sub sign_hash;
sub sign_hash_eth;
sub sign_hash_rfc7518;
sub sign_message;
sub sign_message_rfc7518;
sub size;
sub verify_hash;
sub verify_hash_eth;
sub verify_hash_rfc7518;
sub verify_message;
sub verify_message_rfc7518;
}
package Crypt::PK::Ed25519 {
sub DESTROY;
sub _import;
sub _import_openssh;
sub _import_pem;
sub _import_pkcs8;
sub _import_raw;
sub _import_x509;
sub _new;
sub export_key_der;
sub export_key_raw;
sub generate_key;
sub is_private;
sub key2hash;
sub sign_message;
sub verify_message;
}
package Crypt::PK::RSA {
sub DESTROY;
sub _import;
sub _import_hex;
sub _import_openssh;
sub _import_pem;
sub _import_pkcs8;
sub _import_x509;
sub _new;
sub decrypt;
sub encrypt;
sub export_key_der;
sub generate_key;
sub is_private;
sub key2hash;
sub sign_hash;
sub sign_message;
sub size;
sub verify_hash;
sub verify_message;
}
package Crypt::PK::X25519 {
sub DESTROY;
sub _import;
sub _import_pem;
sub _import_pkcs8;
sub _import_raw;
sub _import_x509;
sub _new;
sub export_key_der;
sub export_key_raw;
sub generate_key;
sub is_private;
sub key2hash;
sub shared_secret;
}
package Crypt::PRNG {
sub DESTROY;
sub add_entropy;
sub bytes;
sub bytes_b64;
sub bytes_b64u;
sub bytes_hex;
sub double;
sub int32;
sub new;
}
package Crypt::Stream::ChaCha {
sub DESTROY;
sub clone;
sub crypt;
sub keystream;
sub new;
}
package Crypt::Stream::RC4 {
sub DESTROY;
sub clone;
sub crypt;
sub keystream;
sub new;
}
package Crypt::Stream::Rabbit {
sub DESTROY;
sub clone;
sub crypt;
sub keystream;
sub new;
}
package Crypt::Stream::Salsa20 {
sub DESTROY;
sub clone;
sub crypt;
sub keystream;
sub new;
}
package Crypt::Stream::Sober128 {
sub DESTROY;
sub clone;
sub crypt;
sub keystream;
sub new;
}
package Crypt::Stream::Sosemanuk {
sub DESTROY;
sub clone;
sub crypt;
sub keystream;
sub new;
}
package CryptX {
sub _ltc_build_settings;
sub _ltc_mp_bits_per_digit;
sub _ltc_mp_name;
}
package Cwd {
sub CLONE;
sub abs_path;
sub fastcwd;
sub getcwd;
sub realpath;
}
package DB {
sub DB_profiler;
sub _CHECK;
sub _END;
sub _INIT;
sub _finish;
sub disable_profile;
sub enable_profile;
sub finish_profile;
sub init_profiler;
sub set_option;
}
package DBD::Pg {
sub PG_ACLITEM() ;
sub PG_ACLITEMARRAY() ;
sub PG_ANY() ;
sub PG_ANYARRAY() ;
sub PG_ANYCOMPATIBLE() ;
sub PG_ANYCOMPATIBLEARRAY() ;
sub PG_ANYCOMPATIBLEMULTIRANGE() ;
sub PG_ANYCOMPATIBLENONARRAY() ;
sub PG_ANYCOMPATIBLERANGE() ;
sub PG_ANYELEMENT() ;
sub PG_ANYENUM() ;
sub PG_ANYMULTIRANGE() ;
sub PG_ANYNONARRAY() ;
sub PG_ANYRANGE() ;
sub PG_ASYNC() ;
sub PG_BIT() ;
sub PG_BITARRAY() ;
sub PG_BOOL() ;
sub PG_BOOLARRAY() ;
sub PG_BOX() ;
sub PG_BOXARRAY() ;
sub PG_BPCHAR() ;
sub PG_BPCHARARRAY() ;
sub PG_BYTEA() ;
sub PG_BYTEAARRAY() ;
sub PG_CHAR() ;
sub PG_CHARARRAY() ;
sub PG_CID() ;
sub PG_CIDARRAY() ;
sub PG_CIDR() ;
sub PG_CIDRARRAY() ;
sub PG_CIRCLE() ;
sub PG_CIRCLEARRAY() ;
sub PG_CSTRING() ;
sub PG_CSTRINGARRAY() ;
sub PG_DATE() ;
sub PG_DATEARRAY() ;
sub PG_DATEMULTIRANGE() ;
sub PG_DATEMULTIRANGEARRAY() ;
sub PG_DATERANGE() ;
sub PG_DATERANGEARRAY() ;
sub PG_EVENT_TRIGGER() ;
sub PG_FDW_HANDLER() ;
sub PG_FLOAT4() ;
sub PG_FLOAT4ARRAY() ;
sub PG_FLOAT8() ;
sub PG_FLOAT8ARRAY() ;
sub PG_GTSVECTOR() ;
sub PG_GTSVECTORARRAY() ;
sub PG_INDEX_AM_HANDLER() ;
sub PG_INET() ;
sub PG_INETARRAY() ;
sub PG_INT2() ;
sub PG_INT2ARRAY() ;
sub PG_INT2VECTOR() ;
sub PG_INT2VECTORARRAY() ;
sub PG_INT4() ;
sub PG_INT4ARRAY() ;
sub PG_INT4MULTIRANGE() ;
sub PG_INT4MULTIRANGEARRAY() ;
sub PG_INT4RANGE() ;
sub PG_INT4RANGEARRAY() ;
sub PG_INT8() ;
sub PG_INT8ARRAY() ;
sub PG_INT8MULTIRANGE() ;
sub PG_INT8MULTIRANGEARRAY() ;
sub PG_INT8RANGE() ;
sub PG_INT8RANGEARRAY() ;
sub PG_INTERNAL() ;
sub PG_INTERVAL() ;
sub PG_INTERVALARRAY() ;
sub PG_JSON() ;
sub PG_JSONARRAY() ;
sub PG_JSONB() ;
sub PG_JSONBARRAY() ;
sub PG_JSONPATH() ;
sub PG_JSONPATHARRAY() ;
sub PG_LANGUAGE_HANDLER() ;
sub PG_LINE() ;
sub PG_LINEARRAY() ;
sub PG_LSEG() ;
sub PG_LSEGARRAY() ;
sub PG_MACADDR() ;
sub PG_MACADDR8() ;
sub PG_MACADDR8ARRAY() ;
sub PG_MACADDRARRAY() ;
sub PG_MONEY() ;
sub PG_MONEYARRAY() ;
sub PG_NAME() ;
sub PG_NAMEARRAY() ;
sub PG_NUMERIC() ;
sub PG_NUMERICARRAY() ;
sub PG_NUMMULTIRANGE() ;
sub PG_NUMMULTIRANGEARRAY() ;
sub PG_NUMRANGE() ;
sub PG_NUMRANGEARRAY() ;
sub PG_OID() ;
sub PG_OIDARRAY() ;
sub PG_OIDVECTOR() ;
sub PG_OIDVECTORARRAY() ;
sub PG_OLDQUERY_CANCEL() ;
sub PG_OLDQUERY_WAIT() ;
sub PG_PATH() ;
sub PG_PATHARRAY() ;
sub PG_PG_ATTRIBUTE() ;
sub PG_PG_ATTRIBUTEARRAY() ;
sub PG_PG_BRIN_BLOOM_SUMMARY() ;
sub PG_PG_BRIN_MINMAX_MULTI_SUMMARY() ;
sub PG_PG_CLASS() ;
sub PG_PG_CLASSARRAY() ;
sub PG_PG_DDL_COMMAND() ;
sub PG_PG_DEPENDENCIES() ;
sub PG_PG_LSN() ;
sub PG_PG_LSNARRAY() ;
sub PG_PG_MCV_LIST() ;
sub PG_PG_NDISTINCT() ;
sub PG_PG_NODE_TREE() ;
sub PG_PG_PROC() ;
sub PG_PG_PROCARRAY() ;
sub PG_PG_SNAPSHOT() ;
sub PG_PG_SNAPSHOTARRAY() ;
sub PG_PG_TYPE() ;
sub PG_PG_TYPEARRAY() ;
sub PG_POINT() ;
sub PG_POINTARRAY() ;
sub PG_POLYGON() ;
sub PG_POLYGONARRAY() ;
sub PG_RECORD() ;
sub PG_RECORDARRAY() ;
sub PG_REFCURSOR() ;
sub PG_REFCURSORARRAY() ;
sub PG_REGCLASS() ;
sub PG_REGCLASSARRAY() ;
sub PG_REGCOLLATION() ;
sub PG_REGCOLLATIONARRAY() ;
sub PG_REGCONFIG() ;
sub PG_REGCONFIGARRAY() ;
sub PG_REGDICTIONARY() ;
sub PG_REGDICTIONARYARRAY() ;
sub PG_REGNAMESPACE() ;
sub PG_REGNAMESPACEARRAY() ;
sub PG_REGOPER() ;
sub PG_REGOPERARRAY() ;
sub PG_REGOPERATOR() ;
sub PG_REGOPERATORARRAY() ;
sub PG_REGPROC() ;
sub PG_REGPROCARRAY() ;
sub PG_REGPROCEDURE() ;
sub PG_REGPROCEDUREARRAY() ;
sub PG_REGROLE() ;
sub PG_REGROLEARRAY() ;
sub PG_REGTYPE() ;
sub PG_REGTYPEARRAY() ;
sub PG_TABLE_AM_HANDLER() ;
sub PG_TEXT() ;
sub PG_TEXTARRAY() ;
sub PG_TID() ;
sub PG_TIDARRAY() ;
sub PG_TIME() ;
sub PG_TIMEARRAY() ;
sub PG_TIMESTAMP() ;
sub PG_TIMESTAMPARRAY() ;
sub PG_TIMESTAMPTZ() ;
sub PG_TIMESTAMPTZARRAY() ;
sub PG_TIMETZ() ;
sub PG_TIMETZARRAY() ;
sub PG_TRIGGER() ;
sub PG_TSMULTIRANGE() ;
sub PG_TSMULTIRANGEARRAY() ;
sub PG_TSM_HANDLER() ;
sub PG_TSQUERY() ;
sub PG_TSQUERYARRAY() ;
sub PG_TSRANGE() ;
sub PG_TSRANGEARRAY() ;
sub PG_TSTZMULTIRANGE() ;
sub PG_TSTZMULTIRANGEARRAY() ;
sub PG_TSTZRANGE() ;
sub PG_TSTZRANGEARRAY() ;
sub PG_TSVECTOR() ;
sub PG_TSVECTORARRAY() ;
sub PG_TXID_SNAPSHOT() ;
sub PG_TXID_SNAPSHOTARRAY() ;
sub PG_UNKNOWN() ;
sub PG_UUID() ;
sub PG_UUIDARRAY() ;
sub PG_VARBIT() ;
sub PG_VARBITARRAY() ;
sub PG_VARCHAR() ;
sub PG_VARCHARARRAY() ;
sub PG_VOID() ;
sub PG_XID() ;
sub PG_XID8() ;
sub PG_XID8ARRAY() ;
sub PG_XIDARRAY() ;
sub PG_XML() ;
sub PG_XMLARRAY() ;
sub constant() ;
}
package DBD::Pg::db {
sub DESTROY;
sub FETCH;
sub SQL_ALL_TYPES() ;
sub SQL_ARRAY() ;
sub SQL_ARRAY_LOCATOR() ;
sub SQL_BIGINT() ;
sub SQL_BINARY() ;
sub SQL_BIT() ;
sub SQL_BLOB() ;
sub SQL_BLOB_LOCATOR() ;
sub SQL_BOOLEAN() ;
sub SQL_CHAR() ;
sub SQL_CLOB() ;
sub SQL_CLOB_LOCATOR() ;
sub SQL_DATE() ;
sub SQL_DATETIME() ;
sub SQL_DECIMAL() ;
sub SQL_DOUBLE() ;
sub SQL_FLOAT() ;
sub SQL_GUID() ;
sub SQL_INTEGER() ;
sub SQL_INTERVAL() ;
sub SQL_INTERVAL_DAY() ;
sub SQL_INTERVAL_DAY_TO_HOUR() ;
sub SQL_INTERVAL_DAY_TO_MINUTE() ;
sub SQL_INTERVAL_DAY_TO_SECOND() ;
sub SQL_INTERVAL_HOUR() ;
sub SQL_INTERVAL_HOUR_TO_MINUTE() ;
sub SQL_INTERVAL_HOUR_TO_SECOND() ;
sub SQL_INTERVAL_MINUTE() ;
sub SQL_INTERVAL_MINUTE_TO_SECOND() ;
sub SQL_INTERVAL_MONTH() ;
sub SQL_INTERVAL_SECOND() ;
sub SQL_INTERVAL_YEAR() ;
sub SQL_INTERVAL_YEAR_TO_MONTH() ;
sub SQL_LONGVARBINARY() ;
sub SQL_LONGVARCHAR() ;
sub SQL_MULTISET() ;
sub SQL_MULTISET_LOCATOR() ;
sub SQL_NUMERIC() ;
sub SQL_REAL() ;
sub SQL_REF() ;
sub SQL_ROW() ;
sub SQL_SMALLINT() ;
sub SQL_TIME() ;
sub SQL_TIMESTAMP() ;
sub SQL_TINYINT() ;
sub SQL_TYPE_DATE() ;
sub SQL_TYPE_TIME() ;
sub SQL_TYPE_TIMESTAMP() ;
sub SQL_TYPE_TIMESTAMP_WITH_TIMEZONE() ;
sub SQL_TYPE_TIME_WITH_TIMEZONE() ;
sub SQL_UDT() ;
sub SQL_UDT_LOCATOR() ;
sub SQL_UNKNOWN_TYPE() ;
sub SQL_VARBINARY() ;
sub SQL_VARCHAR() ;
sub SQL_WCHAR() ;
sub SQL_WLONGVARCHAR() ;
sub SQL_WVARCHAR() ;
sub STORE;
sub _login;
sub _pg_type_info;
sub _ping;
sub commit;
sub disconnect;
sub do($$;$@) ;
sub endcopy;
sub getfd;
sub getline;
sub lo_close;
sub lo_creat;
sub lo_export;
sub lo_import;
sub lo_lseek;
sub lo_open;
sub lo_read;
sub lo_tell;
sub lo_unlink;
sub lo_write;
sub pg_cancel;
sub pg_endcopy;
sub pg_error_field;
sub pg_getcopydata;
sub pg_getcopydata_async;
sub pg_getline;
sub pg_lo_close;
sub pg_lo_creat;
sub pg_lo_export;
sub pg_lo_import;
sub pg_lo_import_with_oid;
sub pg_lo_lseek64;
sub pg_lo_lseek;
sub pg_lo_open;
sub pg_lo_read;
sub pg_lo_tell64;
sub pg_lo_tell;
sub pg_lo_truncate64;
sub pg_lo_truncate;
sub pg_lo_unlink;
sub pg_lo_write;
sub pg_notifies;
sub pg_putcopydata;
sub pg_putcopyend;
sub pg_putline;
sub pg_ready;
sub pg_release;
sub pg_result;
sub pg_rollback_to;
sub pg_savepoint;
sub pg_server_trace;
sub pg_server_untrace;
sub putline;
sub quote;
sub rollback;
sub selectall_arrayref;
sub selectrow_array;
sub selectrow_arrayref;
sub state;
}
package DBD::Pg::dr {
sub dbixs_revision;
sub discon_all_;
sub disconnect_all;
}
package DBD::Pg::st {
sub DESTROY;
sub FETCH;
sub FETCH_attrib;
sub STORE;
sub _prepare;
sub bind_param;
sub bind_param_inout;
sub blob_read;
sub cancel;
sub execute;
sub fetch;
sub fetchall_arrayref;
sub fetchrow;
sub fetchrow_array;
sub fetchrow_arrayref;
sub finish;
sub pg_cancel;
sub pg_canonical_ids;
sub pg_canonical_names;
sub pg_ready;
sub pg_result;
sub rows;
sub state;
}
package DBD::SQLite {
sub ALTER_TABLE() ;
sub ANALYZE() ;
sub ATTACH() ;
sub COPY() ;
sub CREATE_INDEX() ;
sub CREATE_TABLE() ;
sub CREATE_TEMP_INDEX() ;
sub CREATE_TEMP_TABLE() ;
sub CREATE_TEMP_TRIGGER() ;
sub CREATE_TEMP_VIEW() ;
sub CREATE_TRIGGER() ;
sub CREATE_VIEW() ;
sub CREATE_VTABLE() ;
sub DELETE() ;
sub DENY() ;
sub DETACH() ;
sub DROP_INDEX() ;
sub DROP_TABLE() ;
sub DROP_TEMP_INDEX() ;
sub DROP_TEMP_TABLE() ;
sub DROP_TEMP_TRIGGER() ;
sub DROP_TEMP_VIEW() ;
sub DROP_TRIGGER() ;
sub DROP_VIEW() ;
sub DROP_VTABLE() ;
sub FUNCTION() ;
sub IGNORE() ;
sub INSERT() ;
sub OK() ;
sub OPEN_CREATE() ;
sub OPEN_EXRESCODE() ;
sub OPEN_FULLMUTEX() ;
sub OPEN_MEMORY() ;
sub OPEN_NOFOLLOW() ;
sub OPEN_NOMUTEX() ;
sub OPEN_PRIVATECACHE() ;
sub OPEN_READONLY() ;
sub OPEN_READWRITE() ;
sub OPEN_SHAREDCACHE() ;
sub OPEN_SUPER_JOURNAL() ;
sub OPEN_URI() ;
sub PRAGMA() ;
sub READ() ;
sub RECURSIVE() ;
sub REINDEX() ;
sub SAVEPOINT() ;
sub SELECT() ;
sub TRANSACTION() ;
sub UPDATE() ;
sub _const__authorizer_action_codes() ;
sub _const__authorizer_action_codes_3006008() ;
sub _const__authorizer_action_codes_3008003() ;
sub _const__authorizer_return_codes() ;
sub _const__flags_for_file_open_operations() ;
sub _const__flags_for_file_open_operations_3006002() ;
sub _const__flags_for_file_open_operations_3006018() ;
sub _const__flags_for_file_open_operations_3007007() ;
sub _const__flags_for_file_open_operations_3007013() ;
sub _const__flags_for_file_open_operations_3031000() ;
sub _const__flags_for_file_open_operations_3033000() ;
sub _const__flags_for_file_open_operations_3037000() ;
sub compile_options;
sub sqlite_status;
sub strglob;
sub strlike;
}
package DBD::SQLite::Constants {
sub SQLITE_ABORT() ;
sub SQLITE_ABORT_ROLLBACK() ;
sub SQLITE_ALTER_TABLE() ;
sub SQLITE_ANALYZE() ;
sub SQLITE_ATTACH() ;
sub SQLITE_AUTH() ;
sub SQLITE_AUTH_USER() ;
sub SQLITE_BLOB() ;
sub SQLITE_BUSY() ;
sub SQLITE_BUSY_RECOVERY() ;
sub SQLITE_BUSY_SNAPSHOT() ;
sub SQLITE_BUSY_TIMEOUT() ;
sub SQLITE_CANTOPEN() ;
sub SQLITE_CANTOPEN_CONVPATH() ;
sub SQLITE_CANTOPEN_DIRTYWAL() ;
sub SQLITE_CANTOPEN_FULLPATH() ;
sub SQLITE_CANTOPEN_ISDIR() ;
sub SQLITE_CANTOPEN_NOTEMPDIR() ;
sub SQLITE_CANTOPEN_SYMLINK() ;
sub SQLITE_CONSTRAINT() ;
sub SQLITE_CONSTRAINT_CHECK() ;
sub SQLITE_CONSTRAINT_COMMITHOOK() ;
sub SQLITE_CONSTRAINT_DATATYPE() ;
sub SQLITE_CONSTRAINT_FOREIGNKEY() ;
sub SQLITE_CONSTRAINT_FUNCTION() ;
sub SQLITE_CONSTRAINT_NOTNULL() ;
sub SQLITE_CONSTRAINT_PINNED() ;
sub SQLITE_CONSTRAINT_PRIMARYKEY() ;
sub SQLITE_CONSTRAINT_ROWID() ;
sub SQLITE_CONSTRAINT_TRIGGER() ;
sub SQLITE_CONSTRAINT_UNIQUE() ;
sub SQLITE_CONSTRAINT_VTAB() ;
sub SQLITE_COPY() ;
sub SQLITE_CORRUPT() ;
sub SQLITE_CORRUPT_INDEX() ;
sub SQLITE_CORRUPT_SEQUENCE() ;
sub SQLITE_CORRUPT_VTAB() ;
sub SQLITE_CREATE_INDEX() ;
sub SQLITE_CREATE_TABLE() ;
sub SQLITE_CREATE_TEMP_INDEX() ;
sub SQLITE_CREATE_TEMP_TABLE() ;
sub SQLITE_CREATE_TEMP_TRIGGER() ;
sub SQLITE_CREATE_TEMP_VIEW() ;
sub SQLITE_CREATE_TRIGGER() ;
sub SQLITE_CREATE_VIEW() ;
sub SQLITE_CREATE_VTABLE() ;
sub SQLITE_DBCONFIG_DEFENSIVE() ;
sub SQLITE_DBCONFIG_DQS_DDL() ;
sub SQLITE_DBCONFIG_DQS_DML() ;
sub SQLITE_DBCONFIG_ENABLE_FKEY() ;
sub SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER() ;
sub SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION() ;
sub SQLITE_DBCONFIG_ENABLE_QPSG() ;
sub SQLITE_DBCONFIG_ENABLE_TRIGGER() ;
sub SQLITE_DBCONFIG_ENABLE_VIEW() ;
sub SQLITE_DBCONFIG_LEGACY_ALTER_TABLE() ;
sub SQLITE_DBCONFIG_LEGACY_FILE_FORMAT() ;
sub SQLITE_DBCONFIG_LOOKASIDE() ;
sub SQLITE_DBCONFIG_MAINDBNAME() ;
sub SQLITE_DBCONFIG_MAX() ;
sub SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE() ;
sub SQLITE_DBCONFIG_RESET_DATABASE() ;
sub SQLITE_DBCONFIG_REVERSE_SCANORDER() ;
sub SQLITE_DBCONFIG_STMT_SCANSTATUS() ;
sub SQLITE_DBCONFIG_TRIGGER_EQP() ;
sub SQLITE_DBCONFIG_TRUSTED_SCHEMA() ;
sub SQLITE_DBCONFIG_WRITABLE_SCHEMA() ;
sub SQLITE_DELETE() ;
sub SQLITE_DENY() ;
sub SQLITE_DETACH() ;
sub SQLITE_DETERMINISTIC() ;
sub SQLITE_DIRECTONLY() ;
sub SQLITE_DONE() ;
sub SQLITE_DROP_INDEX() ;
sub SQLITE_DROP_TABLE() ;
sub SQLITE_DROP_TEMP_INDEX() ;
sub SQLITE_DROP_TEMP_TABLE() ;
sub SQLITE_DROP_TEMP_TRIGGER() ;
sub SQLITE_DROP_TEMP_VIEW() ;
sub SQLITE_DROP_TRIGGER() ;
sub SQLITE_DROP_VIEW() ;
sub SQLITE_DROP_VTABLE() ;
sub SQLITE_EMPTY() ;
sub SQLITE_ERROR() ;
sub SQLITE_ERROR_MISSING_COLLSEQ() ;
sub SQLITE_ERROR_RETRY() ;
sub SQLITE_ERROR_SNAPSHOT() ;
sub SQLITE_FLOAT() ;
sub SQLITE_FORMAT() ;
sub SQLITE_FULL() ;
sub SQLITE_FUNCTION() ;
sub SQLITE_IGNORE() ;
sub SQLITE_INNOCUOUS() ;
sub SQLITE_INSERT() ;
sub SQLITE_INTEGER() ;
sub SQLITE_INTERNAL() ;
sub SQLITE_INTERRUPT() ;
sub SQLITE_IOERR() ;
sub SQLITE_IOERR_ACCESS() ;
sub SQLITE_IOERR_AUTH() ;
sub SQLITE_IOERR_BEGIN_ATOMIC() ;
sub SQLITE_IOERR_BLOCKED() ;
sub SQLITE_IOERR_CHECKRESERVEDLOCK() ;
sub SQLITE_IOERR_CLOSE() ;
sub SQLITE_IOERR_COMMIT_ATOMIC() ;
sub SQLITE_IOERR_CONVPATH() ;
sub SQLITE_IOERR_CORRUPTFS() ;
sub SQLITE_IOERR_DATA() ;
sub SQLITE_IOERR_DELETE() ;
sub SQLITE_IOERR_DELETE_NOENT() ;
sub SQLITE_IOERR_DIR_CLOSE() ;
sub SQLITE_IOERR_DIR_FSYNC() ;
sub SQLITE_IOERR_FSTAT() ;
sub SQLITE_IOERR_FSYNC() ;
sub SQLITE_IOERR_GETTEMPPATH() ;
sub SQLITE_IOERR_IN_PAGE() ;
sub SQLITE_IOERR_LOCK() ;
sub SQLITE_IOERR_MMAP() ;
sub SQLITE_IOERR_NOMEM() ;
sub SQLITE_IOERR_RDLOCK() ;
sub SQLITE_IOERR_READ() ;
sub SQLITE_IOERR_ROLLBACK_ATOMIC() ;
sub SQLITE_IOERR_SEEK() ;
sub SQLITE_IOERR_SHMLOCK() ;
sub SQLITE_IOERR_SHMMAP() ;
sub SQLITE_IOERR_SHMOPEN() ;
sub SQLITE_IOERR_SHMSIZE() ;
sub SQLITE_IOERR_SHORT_READ() ;
sub SQLITE_IOERR_TRUNCATE() ;
sub SQLITE_IOERR_UNLOCK() ;
sub SQLITE_IOERR_VNODE() ;
sub SQLITE_IOERR_WRITE() ;
sub SQLITE_LIMIT_ATTACHED() ;
sub SQLITE_LIMIT_COLUMN() ;
sub SQLITE_LIMIT_COMPOUND_SELECT() ;
sub SQLITE_LIMIT_EXPR_DEPTH() ;
sub SQLITE_LIMIT_FUNCTION_ARG() ;
sub SQLITE_LIMIT_LENGTH() ;
sub SQLITE_LIMIT_LIKE_PATTERN_LENGTH() ;
sub SQLITE_LIMIT_SQL_LENGTH() ;
sub SQLITE_LIMIT_TRIGGER_DEPTH() ;
sub SQLITE_LIMIT_VARIABLE_NUMBER() ;
sub SQLITE_LIMIT_VDBE_OP() ;
sub SQLITE_LIMIT_WORKER_THREADS() ;
sub SQLITE_LOCKED() ;
sub SQLITE_LOCKED_SHAREDCACHE() ;
sub SQLITE_LOCKED_VTAB() ;
sub SQLITE_MISMATCH() ;
sub SQLITE_MISUSE() ;
sub SQLITE_NOLFS() ;
sub SQLITE_NOMEM() ;
sub SQLITE_NOTADB() ;
sub SQLITE_NOTFOUND() ;
sub SQLITE_NOTICE() ;
sub SQLITE_NOTICE_RBU() ;
sub SQLITE_NOTICE_RECOVER_ROLLBACK() ;
sub SQLITE_NOTICE_RECOVER_WAL() ;
sub SQLITE_NULL() ;
sub SQLITE_OK() ;
sub SQLITE_OK_SYMLINK() ;
sub SQLITE_OPEN_CREATE() ;
sub SQLITE_OPEN_EXRESCODE() ;
sub SQLITE_OPEN_FULLMUTEX() ;
sub SQLITE_OPEN_MEMORY() ;
sub SQLITE_OPEN_NOFOLLOW() ;
sub SQLITE_OPEN_NOMUTEX() ;
sub SQLITE_OPEN_PRIVATECACHE() ;
sub SQLITE_OPEN_READONLY() ;
sub SQLITE_OPEN_READWRITE() ;
sub SQLITE_OPEN_SHAREDCACHE() ;
sub SQLITE_OPEN_SUPER_JOURNAL() ;
sub SQLITE_OPEN_URI() ;
sub SQLITE_PERM() ;
sub SQLITE_PRAGMA() ;
sub SQLITE_PROTOCOL() ;
sub SQLITE_RANGE() ;
sub SQLITE_READ() ;
sub SQLITE_READONLY() ;
sub SQLITE_READONLY_CANTINIT() ;
sub SQLITE_READONLY_CANTLOCK() ;
sub SQLITE_READONLY_DBMOVED() ;
sub SQLITE_READONLY_DIRECTORY() ;
sub SQLITE_READONLY_RECOVERY() ;
sub SQLITE_READONLY_ROLLBACK() ;
sub SQLITE_RECURSIVE() ;
sub SQLITE_REINDEX() ;
sub SQLITE_RESULT_SUBTYPE() ;
sub SQLITE_ROW() ;
sub SQLITE_SAVEPOINT() ;
sub SQLITE_SCHEMA() ;
sub SQLITE_SELECT() ;
sub SQLITE_SUBTYPE() ;
sub SQLITE_TEXT() ;
sub SQLITE_TOOBIG() ;
sub SQLITE_TRANSACTION() ;
sub SQLITE_TXN_NONE() ;
sub SQLITE_TXN_READ() ;
sub SQLITE_TXN_WRITE() ;
sub SQLITE_UPDATE() ;
sub SQLITE_VERSION_NUMBER() ;
sub SQLITE_WARNING() ;
sub SQLITE_WARNING_AUTOINDEX() ;
sub _const_allowed_return_values_from_sqlite3_txn_state_3034000() ;
sub _const_authorizer_action_codes() ;
sub _const_authorizer_action_codes_3006008() ;
sub _const_authorizer_action_codes_3008003() ;
sub _const_authorizer_return_codes() ;
sub _const_compile_time_library_version_numbers() ;
sub _const_database_connection_configuration_options_3007000() ;
sub _const_database_connection_configuration_options_3007006() ;
sub _const_database_connection_configuration_options_3012002() ;
sub _const_database_connection_configuration_options_3013000() ;
sub _const_database_connection_configuration_options_3015000() ;
sub _const_database_connection_configuration_options_3016000() ;
sub _const_database_connection_configuration_options_3020000() ;
sub _const_database_connection_configuration_options_3022000() ;
sub _const_database_connection_configuration_options_3024000() ;
sub _const_database_connection_configuration_options_3026000() ;
sub _const_database_connection_configuration_options_3028000() ;
sub _const_database_connection_configuration_options_3029000() ;
sub _const_database_connection_configuration_options_3030000() ;
sub _const_database_connection_configuration_options_3031000() ;
sub _const_database_connection_configuration_options_3042000() ;
sub _const_extended_result_codes_3006002() ;
sub _const_extended_result_codes_3006005() ;
sub _const_extended_result_codes_3006007() ;
sub _const_extended_result_codes_3006012() ;
sub _const_extended_result_codes_3007000() ;
sub _const_extended_result_codes_3007007() ;
sub _const_extended_result_codes_3007011() ;
sub _const_extended_result_codes_3007012() ;
sub _const_extended_result_codes_3007015() ;
sub _const_extended_result_codes_3007016() ;
sub _const_extended_result_codes_3007017() ;
sub _const_extended_result_codes_3008000() ;
sub _const_extended_result_codes_3008001() ;
sub _const_extended_result_codes_3008002() ;
sub _const_extended_result_codes_3008003() ;
sub _const_extended_result_codes_3008007() ;
sub _const_extended_result_codes_3009000() ;
sub _const_extended_result_codes_3010000() ;
sub _const_extended_result_codes_3021000() ;
sub _const_extended_result_codes_3022000() ;
sub _const_extended_result_codes_3024000() ;
sub _const_extended_result_codes_3025000() ;
sub _const_extended_result_codes_3031000() ;
sub _const_extended_result_codes_3032000() ;
sub _const_extended_result_codes_3034000() ;
sub _const_extended_result_codes_3037000() ;
sub _const_extended_result_codes_3041000() ;
sub _const_extended_result_codes_3043000() ;
sub _const_flags_for_file_open_operations() ;
sub _const_flags_for_file_open_operations_3006002() ;
sub _const_flags_for_file_open_operations_3006018() ;
sub _const_flags_for_file_open_operations_3007007() ;
sub _const_flags_for_file_open_operations_3007013() ;
sub _const_flags_for_file_open_operations_3031000() ;
sub _const_flags_for_file_open_operations_3033000() ;
sub _const_flags_for_file_open_operations_3037000() ;
sub _const_function_flags_3008003() ;
sub _const_function_flags_3030000() ;
sub _const_function_flags_3031000() ;
sub _const_function_flags_3044001() ;
sub _const_fundamental_datatypes() ;
sub _const_result_codes() ;
sub _const_result_codes_3007017() ;
sub _const_run_time_limit_categories() ;
sub _const_run_time_limit_categories_3006018() ;
sub _const_run_time_limit_categories_3008007() ;
}
package DBD::SQLite::db {
sub DESTROY;
sub FETCH;
sub SQL_ALL_TYPES() ;
sub SQL_ARRAY() ;
sub SQL_ARRAY_LOCATOR() ;
sub SQL_BIGINT() ;
sub SQL_BINARY() ;
sub SQL_BIT() ;
sub SQL_BLOB() ;
sub SQL_BLOB_LOCATOR() ;
sub SQL_BOOLEAN() ;
sub SQL_CHAR() ;
sub SQL_CLOB() ;
sub SQL_CLOB_LOCATOR() ;
sub SQL_DATE() ;
sub SQL_DATETIME() ;
sub SQL_DECIMAL() ;
sub SQL_DOUBLE() ;
sub SQL_FLOAT() ;
sub SQL_GUID() ;
sub SQL_INTEGER() ;
sub SQL_INTERVAL() ;
sub SQL_INTERVAL_DAY() ;
sub SQL_INTERVAL_DAY_TO_HOUR() ;
sub SQL_INTERVAL_DAY_TO_MINUTE() ;
sub SQL_INTERVAL_DAY_TO_SECOND() ;
sub SQL_INTERVAL_HOUR() ;
sub SQL_INTERVAL_HOUR_TO_MINUTE() ;
sub SQL_INTERVAL_HOUR_TO_SECOND() ;
sub SQL_INTERVAL_MINUTE() ;
sub SQL_INTERVAL_MINUTE_TO_SECOND() ;
sub SQL_INTERVAL_MONTH() ;
sub SQL_INTERVAL_SECOND() ;
sub SQL_INTERVAL_YEAR() ;
sub SQL_INTERVAL_YEAR_TO_MONTH() ;
sub SQL_LONGVARBINARY() ;
sub SQL_LONGVARCHAR() ;
sub SQL_MULTISET() ;
sub SQL_MULTISET_LOCATOR() ;
sub SQL_NUMERIC() ;
sub SQL_REAL() ;
sub SQL_REF() ;
sub SQL_ROW() ;
sub SQL_SMALLINT() ;
sub SQL_TIME() ;
sub SQL_TIMESTAMP() ;
sub SQL_TINYINT() ;
sub SQL_TYPE_DATE() ;
sub SQL_TYPE_TIME() ;
sub SQL_TYPE_TIMESTAMP() ;
sub SQL_TYPE_TIMESTAMP_WITH_TIMEZONE() ;
sub SQL_TYPE_TIME_WITH_TIMEZONE() ;
sub SQL_UDT() ;
sub SQL_UDT_LOCATOR() ;
sub SQL_UNKNOWN_TYPE() ;
sub SQL_VARBINARY() ;
sub SQL_VARCHAR() ;
sub SQL_WCHAR() ;
sub SQL_WLONGVARCHAR() ;
sub SQL_WVARCHAR() ;
sub STORE;
sub _do;
sub _login;
sub backup_from_dbh;
sub backup_from_file;
sub backup_to_dbh;
sub backup_to_file;
sub busy_timeout;
sub collation_needed;
sub commit;
sub commit_hook;
sub create_aggregate;
sub create_collation;
sub create_function;
sub create_module;
sub db_config;
sub db_filename;
sub db_status;
sub disconnect;
sub enable_load_extension;
sub error_offset;
sub get_autocommit;
sub last_insert_id;
sub last_insert_rowid;
sub limit;
sub load_extension;
sub profile;
sub progress_handler;
sub register_fts3_perl_tokenizer;
sub rollback;
sub rollback_hook;
sub selectall_arrayref;
sub selectrow_array;
sub selectrow_arrayref;
sub set_authorizer;
sub sqlite_backup_from_dbh;
sub sqlite_backup_from_file;
sub sqlite_backup_to_dbh;
sub sqlite_backup_to_file;
sub sqlite_busy_timeout;
sub sqlite_collation_needed;
sub sqlite_commit_hook;
sub sqlite_create_aggregate;
sub sqlite_create_collation;
sub sqlite_create_function;
sub sqlite_create_module;
sub sqlite_db_config;
sub sqlite_db_filename;
sub sqlite_db_status;
sub sqlite_enable_load_extension;
sub sqlite_error_offset;
sub sqlite_get_autocommit;
sub sqlite_last_insert_rowid;
sub sqlite_limit;
sub sqlite_load_extension;
sub sqlite_profile;
sub sqlite_progress_handler;
sub sqlite_register_fts3_perl_tokenizer;
sub sqlite_rollback_hook;
sub sqlite_set_authorizer;
sub sqlite_table_column_metadata;
sub sqlite_trace;
sub sqlite_txn_state;
sub sqlite_update_hook;
sub table_column_metadata;
sub txn_state;
sub update_hook;
}
package DBD::SQLite::dr {
sub dbixs_revision;
sub discon_all_;
sub disconnect_all;
}
package DBD::SQLite::st {
sub DESTROY;
sub FETCH;
sub FETCH_attrib;
sub STORE;
sub _prepare;
sub bind_col;
sub bind_param;
sub bind_param_inout;
sub blob_read;
sub execute;
sub fetch;
sub fetchall_arrayref;
sub fetchrow;
sub fetchrow_array;
sub fetchrow_arrayref;
sub finish;
sub rows;
sub sqlite_st_status;
sub st_status;
}
package DBD::_::common {
sub DELETE;
sub DESTROY;
sub FETCH;
sub STORE;
sub debug;
sub dump_handle;
sub err;
sub errstr;
sub private_data;
sub rows;
sub set_err;
sub state;
sub swap_inner_handle;
sub trace;
sub trace_msg;
}
package DBD::_::db {
sub connected;
sub preparse;
sub take_imp_data;
}
package DBD::_::dr {
sub dbixs_revision;
}
package DBD::_::st {
sub DESTROY;
sub _get_fbav;
sub _set_fbav;
sub bind_col;
sub fetch;
sub fetchrow;
sub fetchrow_array;
sub fetchrow_arrayref;
sub fetchrow_hashref;
sub finish;
sub rows;
}
package DBD::_mem::common {
sub DESTROY;
}
package DBI {
sub DBIf_TRACE_CON() ;
sub DBIf_TRACE_DBD() ;
sub DBIf_TRACE_ENC() ;
sub DBIf_TRACE_SQL() ;
sub DBIf_TRACE_TXN() ;
sub DBIpp_cm_XX() ;
sub DBIpp_cm_br() ;
sub DBIpp_cm_cs() ;
sub DBIpp_cm_dd() ;
sub DBIpp_cm_dw() ;
sub DBIpp_cm_hs() ;
sub DBIpp_ph_XX() ;
sub DBIpp_ph_cn() ;
sub DBIpp_ph_cs() ;
sub DBIpp_ph_qm() ;
sub DBIpp_ph_sp() ;
sub DBIpp_st_XX() ;
sub DBIpp_st_bs() ;
sub DBIpp_st_qq() ;
sub DBIstcf_DISCARD_STRING() ;
sub DBIstcf_STRICT() ;
sub SQL_ALL_TYPES() ;
sub SQL_ARRAY() ;
sub SQL_ARRAY_LOCATOR() ;
sub SQL_BIGINT() ;
sub SQL_BINARY() ;
sub SQL_BIT() ;
sub SQL_BLOB() ;
sub SQL_BLOB_LOCATOR() ;
sub SQL_BOOLEAN() ;
sub SQL_CHAR() ;
sub SQL_CLOB() ;
sub SQL_CLOB_LOCATOR() ;
sub SQL_CURSOR_DYNAMIC() ;
sub SQL_CURSOR_FORWARD_ONLY() ;
sub SQL_CURSOR_KEYSET_DRIVEN() ;
sub SQL_CURSOR_STATIC() ;
sub SQL_CURSOR_TYPE_DEFAULT() ;
sub SQL_DATE() ;
sub SQL_DATETIME() ;
sub SQL_DECIMAL() ;
sub SQL_DOUBLE() ;
sub SQL_FLOAT() ;
sub SQL_GUID() ;
sub SQL_INTEGER() ;
sub SQL_INTERVAL() ;
sub SQL_INTERVAL_DAY() ;
sub SQL_INTERVAL_DAY_TO_HOUR() ;
sub SQL_INTERVAL_DAY_TO_MINUTE() ;
sub SQL_INTERVAL_DAY_TO_SECOND() ;
sub SQL_INTERVAL_HOUR() ;
sub SQL_INTERVAL_HOUR_TO_MINUTE() ;
sub SQL_INTERVAL_HOUR_TO_SECOND() ;
sub SQL_INTERVAL_MINUTE() ;
sub SQL_INTERVAL_MINUTE_TO_SECOND() ;
sub SQL_INTERVAL_MONTH() ;
sub SQL_INTERVAL_SECOND() ;
sub SQL_INTERVAL_YEAR() ;
sub SQL_INTERVAL_YEAR_TO_MONTH() ;
sub SQL_LONGVARBINARY() ;
sub SQL_LONGVARCHAR() ;
sub SQL_MULTISET() ;
sub SQL_MULTISET_LOCATOR() ;
sub SQL_NUMERIC() ;
sub SQL_REAL() ;
sub SQL_REF() ;
sub SQL_ROW() ;
sub SQL_SMALLINT() ;
sub SQL_TIME() ;
sub SQL_TIMESTAMP() ;
sub SQL_TINYINT() ;
sub SQL_TYPE_DATE() ;
sub SQL_TYPE_TIME() ;
sub SQL_TYPE_TIMESTAMP() ;
sub SQL_TYPE_TIMESTAMP_WITH_TIMEZONE() ;
sub SQL_TYPE_TIME_WITH_TIMEZONE() ;
sub SQL_UDT() ;
sub SQL_UDT_LOCATOR() ;
sub SQL_UNKNOWN_TYPE() ;
sub SQL_VARBINARY() ;
sub SQL_VARCHAR() ;
sub SQL_WCHAR() ;
sub SQL_WLONGVARCHAR() ;
sub SQL_WVARCHAR() ;
sub _clone_dbis;
sub _concat_hash_sorted;
sub _dbi_state_lval;
sub _debug_dispatch;
sub _get_imp_data;
sub _handles;
sub _install_method;
sub _new_handle;
sub _setup_handle;
sub _svdump;
sub constant() ;
sub dbi_profile;
sub dbi_profile_merge;
sub dbi_profile_merge_nodes;
sub dbi_time;
sub dump_handle;
sub hash;
sub looks_like_number;
sub neat;
sub set_err;
sub sql_type_cast;
sub trace;
sub trace_msg;
}
package DBI::common {
sub CLEAR;
sub DELETE;
sub DESTROY;
sub EXISTS;
sub FETCH;
sub FETCH_many;
sub FIRSTKEY;
sub NEXTKEY;
sub STORE;
sub can;
sub debug;
sub dump_handle;
sub err;
sub errstr;
sub func;
sub parse_trace_flag;
sub parse_trace_flags;
sub private_attribute_info;
sub private_data;
sub set_err;
sub state;
sub swap_inner_handle;
sub trace;
sub trace_msg;
sub visit_child_handles;
}
package DBI::db {
sub TIEHASH;
sub begin_work;
sub clone;
sub column_info;
sub commit;
sub connected;
sub data_sources;
sub disconnect;
sub do;
sub foreign_key_info;
sub get_info;
sub last_insert_id;
sub ping;
sub prepare;
sub prepare_cached;
sub preparse;
sub primary_key;
sub primary_key_info;
sub quote;
sub quote_identifier;
sub rollback;
sub rows;
sub selectall_array;
sub selectall_arrayref;
sub selectall_hashref;
sub selectcol_arrayref;
sub selectrow_array;
sub selectrow_arrayref;
sub selectrow_hashref;
sub statistics_info;
sub table_info;
sub tables;
sub take_imp_data;
sub type_info;
sub type_info_all;
}
package DBI::dr {
sub TIEHASH;
sub connect;
sub connect_cached;
sub data_sources;
sub dbixs_revision;
sub default_user;
sub disconnect_all;
}
package DBI::st {
sub TIEHASH;
sub _get_fbav;
sub _set_fbav;
sub bind_col;
sub bind_columns;
sub bind_param;
sub bind_param_array;
sub bind_param_inout;
sub bind_param_inout_array;
sub blob_copy_to_file;
sub blob_read;
sub cancel;
sub dump_results;
sub execute;
sub execute_array;
sub execute_for_fetch;
sub fetch;
sub fetchall_arrayref;
sub fetchall_hashref;
sub fetchrow;
sub fetchrow_array;
sub fetchrow_arrayref;
sub fetchrow_hashref;
sub finish;
sub last_insert_id;
sub more_results;
sub rows;
}
package DBI::var {
sub FETCH;
}
package Data::Dumper {
sub Dumpxs($;$$) ;
sub _vstring($) ;
}
package DateTime {
sub _accumulated_leap_seconds($$) ;
sub _day_has_leap_second($$) ;
sub _day_length($$) ;
sub _is_leap_year($$) ;
sub _normalize_leap_seconds($$$) ;
sub _normalize_tai_seconds($$$) ;
sub _rd2ymd($$;$) ;
sub _seconds_as_components($$;$$) ;
sub _time_as_seconds($$$$) ;
sub _ymd2rd($$$$) ;
}
package Devel::Cover {
sub abs_path;
sub getcwd;
sub main_cv;
sub main_root;
sub ppname;
}
package Devel::Cover::Util {
sub abs_path;
}
package Devel::NYTProf::Data {
sub load_profile_data_from_file;
}
package Devel::NYTProf::Test {
sub example_xsub;
sub example_xsub_eval;
sub set_errno;
sub ticks_for_usleep;
}
package Devel::NYTProf::Util {
sub trace_level;
}
package Devel::OverloadInfo {
sub blessed($) ;
sub subname;
}
package Devel::Peek {
sub CvGV;
sub DeadCode;
sub Dump;
sub DumpArray;
sub DumpProg;
sub SvREFCNT(\[$@%&*]) ;
sub fill_mstats;
sub mstat;
sub mstats2hash($\%;$) ;
sub mstats_fillhash(\%;$) ;
sub runops_debug;
}
package Devel::StackTrace {
sub blessed($) ;
}
package Digest::MD5 {
sub DESTROY;
sub add;
sub addfile;
sub b64digest;
sub clone;
sub context;
sub digest;
sub hexdigest;
sub md5;
sub md5_base64;
sub md5_hex;
sub new;
sub reset;
}
package Digest::SHA {
sub DESTROY($) ;
sub _addfilebin($$) ;
sub _addfileuniv($$) ;
sub _getstate($) ;
sub _putstate($$) ;
sub add($;@) ;
sub algorithm($) ;
sub b64digest($) ;
sub clone($) ;
sub digest($) ;
sub getcwd;
sub hashsize($) ;
sub hexdigest($) ;
sub hmac_sha1(;@) ;
sub hmac_sha1_base64(;@) ;
sub hmac_sha1_hex(;@) ;
sub hmac_sha224(;@) ;
sub hmac_sha224_base64(;@) ;
sub hmac_sha224_hex(;@) ;
sub hmac_sha256(;@) ;
sub hmac_sha256_base64(;@) ;
sub hmac_sha256_hex(;@) ;
sub hmac_sha384(;@) ;
sub hmac_sha384_base64(;@) ;
sub hmac_sha384_hex(;@) ;
sub hmac_sha512(;@) ;
sub hmac_sha512224(;@) ;
sub hmac_sha512224_base64(;@) ;
sub hmac_sha512224_hex(;@) ;
sub hmac_sha512256(;@) ;
sub hmac_sha512256_base64(;@) ;
sub hmac_sha512256_hex(;@) ;
sub hmac_sha512_base64(;@) ;
sub hmac_sha512_hex(;@) ;
sub newSHA($$) ;
sub sha1(;@) ;
sub sha1_base64(;@) ;
sub sha1_hex(;@) ;
sub sha224(;@) ;
sub sha224_base64(;@) ;
sub sha224_hex(;@) ;
sub sha256(;@) ;
sub sha256_base64(;@) ;
sub sha256_hex(;@) ;
sub sha384(;@) ;
sub sha384_base64(;@) ;
sub sha384_hex(;@) ;
sub sha512(;@) ;
sub sha512224(;@) ;
sub sha512224_base64(;@) ;
sub sha512224_hex(;@) ;
sub sha512256(;@) ;
sub sha512256_base64(;@) ;
sub sha512256_hex(;@) ;
sub sha512_base64(;@) ;
sub sha512_hex(;@) ;
sub shainit($$) ;
sub sharewind($) ;
sub shawrite($$$) ;
}
package Digest::base {
sub add;
sub clone;
sub digest;
sub new;
}
package DynaLoader {
sub CLONE;
sub boot_DynaLoader;
sub dl_error;
sub dl_find_symbol;
sub dl_install_xsub;
sub dl_load_file;
sub dl_undef_symbols;
sub dl_unload_file;
}
package EV {
sub _ae_io($$$) ;
sub async($) ;
sub async_ns($) ;
sub backend() ;
sub break(;$) ;
sub check($) ;
sub check_ns($) ;
sub child($$$) ;
sub child_ns($$$) ;
sub default_destroy() ;
sub default_loop(;$) ;
sub depth() ;
sub embed($;$) ;
sub embed_ns($;$) ;
sub embeddable_backends() ;
sub feed_fd_event($;$) ;
sub feed_signal($) ;
sub feed_signal_event($) ;
sub fork($) ;
sub fork_ns($) ;
sub idle($) ;
sub idle_ns($) ;
sub invoke_pending() ;
sub io($$$) ;
sub io_ns($$$) ;
sub iteration() ;
sub loop(;$) ;
sub loop_count() ;
sub loop_depth() ;
sub loop_verify() ;
sub now() ;
sub now_update() ;
sub once($$$$) ;
sub pending_count() ;
sub periodic($$$$) ;
sub periodic_ns($$$$) ;
sub prepare($) ;
sub prepare_ns($) ;
sub recommended_backends() ;
sub resume() ;
sub run(;$) ;
sub set_io_collect_interval($) ;
sub set_timeout_collect_interval($) ;
sub signal($$) ;
sub signal_ns($$) ;
sub sleep($) ;
sub stat($$$) ;
sub stat_ns($$$) ;
sub supported_backends() ;
sub suspend() ;
sub time() ;
sub timer($$$) ;
sub timer_ns($$$) ;
sub unloop(;$) ;
sub verify() ;
}
package EV::Async {
sub DESTROY;
sub async_pending;
sub send;
sub start;
sub stop;
}
package EV::Check {
sub DESTROY;
sub start;
sub stop;
}
package EV::Child {
sub DESTROY;
sub pid;
sub reinit;
sub rpid;
sub rstatus;
sub set;
sub start;
sub stop;
}
package EV::Embed {
sub DESTROY;
sub other;
sub set;
sub start;
sub stop;
sub sweep;
}
package EV::Fork {
sub DESTROY;
sub start;
sub stop;
}
package EV::IO {
sub DESTROY;
sub events;
sub fh;
sub set;
sub start;
sub stop;
}
package EV::Idle {
sub DESTROY;
sub start;
sub stop;
}
package EV::Loop {
sub DESTROY;
sub async;
sub async_ns;
sub backend;
sub break;
sub check;
sub check_ns;
sub child;
sub child_ns;
sub depth;
sub embed;
sub embed_ns;
sub feed_fd_event;
sub fork;
sub fork_ns;
sub idle;
sub idle_ns;
sub invoke_pending;
sub io;
sub io_ns;
sub iteration;
sub loop;
sub loop_count;
sub loop_depth;
sub loop_fork;
sub loop_verify;
sub new;
sub now;
sub now_update;
sub once;
sub pending_count;
sub periodic;
sub periodic_ns;
sub prepare;
sub prepare_ns;
sub resume;
sub run;
sub set_io_collect_interval;
sub set_timeout_collect_interval;
sub signal;
sub signal_ns;
sub stat;
sub stat_ns;
sub suspend;
sub timer;
sub timer_ns;
sub unloop;
sub verify;
}
package EV::Periodic {
sub DESTROY;
sub again;
sub at;
sub interval;
sub offset;
sub reschedule_cb;
sub set;
sub start;
sub stop;
}
package EV::Prepare {
sub DESTROY;
sub start;
sub stop;
}
package EV::Signal {
sub DESTROY;
sub set;
sub signal;
sub start;
sub stop;
}
package EV::Stat {
sub DESTROY;
sub attr;
sub interval;
sub path;
sub prev;
sub set;
sub start;
sub stat;
sub stop;
}
package EV::Timer {
sub DESTROY;
sub again;
sub remaining;
sub repeat;
sub set;
sub start;
sub stop;
}
package EV::Watcher {
sub cb;
sub clear_pending;
sub data;
sub feed_event;
sub invoke;
sub is_active;
sub is_pending;
sub keepalive;
sub loop;
sub priority;
}
package Encode {
sub _utf8_off($) ;
sub _utf8_on($) ;
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub from_to($$$;$) ;
sub is_utf8($;$) ;
sub onBOOT() ;
sub str2bytes($$;$) ;
}
package Encode::Byte {
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub str2bytes($$;$) ;
}
package Encode::CN {
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub str2bytes($$;$) ;
}
package Encode::EBCDIC {
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub str2bytes($$;$) ;
}
package Encode::JP {
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub str2bytes($$;$) ;
}
package Encode::KR {
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub str2bytes($$;$) ;
}
package Encode::Symbol {
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub str2bytes($$;$) ;
}
package Encode::TW {
sub bytes2str($$;$) ;
sub decode($$;$) ;
sub decode_utf8($;$) ;
sub encode($$;$) ;
sub encode_utf8($) ;
sub str2bytes($$;$) ;
}
package Encode::Unicode {
sub decode;
sub encode;
}
package Encode::XS {
sub cat_decode;
sub decode;
sub encode;
sub mime_name;
sub name;
sub needs_lines;
sub perlio_ok;
sub renew;
sub renewed;
}
package Encode::utf8 {
sub decode;
sub encode;
}
package Eval::Closure {
sub reftype($) ;
}
package Exception::Class {
sub blessed($) ;
sub reftype($) ;
}
package Exception::Class::Base {
sub blessed($) ;
}
package Fcntl {
sub AUTOLOAD;
sub FCREAT() ;
sub FDEFER() ;
sub FDSYNC() ;
sub FEXCL() ;
sub FLARGEFILE() ;
sub FRSYNC() ;
sub FSYNC() ;
sub FTRUNC() ;
sub F_ALLOCSP() ;
sub F_ALLOCSP64() ;
sub F_COMPAT() ;
sub F_DUP2FD() ;
sub F_FREESP() ;
sub F_FREESP64() ;
sub F_FSYNC() ;
sub F_FSYNC64() ;
sub F_NODNY() ;
sub F_POSIX() ;
sub F_RDACC() ;
sub F_RDDNY() ;
sub F_RWACC() ;
sub F_RWDNY() ;
sub F_SHARE() ;
sub F_UNSHARE() ;
sub F_WRACC() ;
sub F_WRDNY() ;
sub O_ALIAS() ;
sub O_ALT_IO() ;
sub O_DEFER() ;
sub O_EVTONLY() ;
sub O_EXLOCK() ;
sub O_IGNORE_CTTY() ;
sub O_NOINHERIT() ;
sub O_NOLINK() ;
sub O_NOSIGPIPE() ;
sub O_NOTRANS() ;
sub O_RANDOM() ;
sub O_RAW() ;
sub O_RSRC() ;
sub O_SEQUENTIAL() ;
sub O_SHLOCK() ;
sub O_SYMLINK() ;
sub O_TEMPORARY() ;
sub O_TTY_INIT() ;
sub S_ENFMT() ;
sub S_IFMT;
sub S_IFWHT() ;
sub S_IMODE;
sub S_ISBLK;
sub S_ISCHR;
sub S_ISDIR;
sub S_ISFIFO;
sub S_ISLNK;
sub S_ISREG;
sub S_ISSOCK;
sub S_ISTXT() ;
}
package File::DosGlob {
sub _callsite;
}
package File::Find {
sub is_tainted($) ;
}
package File::Glob {
sub AUTOLOAD;
sub CLONE;
sub GLOB_ERROR;
sub bsd_glob;
sub bsd_glob_override;
sub csh_glob;
}
package File::GlobMapper {
sub GLOB_ERROR;
sub bsd_glob;
sub globber;
}
package File::Map {
sub advise;
sub broadcast;
sub lock_map;
sub map_anonymous;
sub map_file;
sub map_handle;
sub notify;
sub pin;
sub protect;
sub remap;
sub sync;
sub sys_map;
sub unmap;
sub unpin;
sub wait_until(&@) ;
}
package File::Path {
sub getcwd;
}
package File::ShareDir {
sub _STRING($) ;
}
package File::Spec::Unix {
sub _fn_canonpath;
sub _fn_catdir;
sub _fn_catfile;
sub canonpath;
sub catdir;
sub catfile;
}
package Filter::Util::Call {
sub filter_del() ;
sub filter_read(;$) ;
sub real_import($$$) ;
sub unimport(;$@) ;
}
package Future::AsyncAwait {
sub __cxstack_ix;
}
package Future::PP {
sub blessed($) ;
sub gettimeofday() ;
sub pairkeys(@) ;
sub pairs(@) ;
sub reftype($) ;
sub weaken($) ;
}
package Future::_base {
sub blessed($) ;
sub svref_2object;
}
package HTML::Entities {
sub UNICODE_SUPPORT() ;
sub _decode_entities;
sub _probably_utf8_chunk;
sub decode;
sub decode_entities;
}
package HTML::Parser {
sub _alloc_pstate;
sub attr_encoded;
sub backquote;
sub boolean_attribute_value;
sub case_sensitive;
sub closing_plaintext;
sub empty_element_tags;
sub eof;
sub handler;
sub ignore_elements;
sub ignore_tags;
sub marked_sections;
sub parse;
sub report_tags;
sub strict_comment;
sub strict_end;
sub strict_names;
sub unbroken_text;
sub utf8_mode;
sub xml_mode;
sub xml_pic;
}
package Hash::StoredIterator {
sub hash_get_iterator;
sub hash_init_iterator;
sub hash_set_iterator;
}
package Hash::Util {
sub _clear_placeholders(\%) ;
sub all_keys(\%\@\@) ;
sub bucket_array;
sub bucket_info;
sub bucket_ratio(\%) ;
sub hash_seed() ;
sub hash_traversal_mask;
sub hash_value($;$) ;
sub hidden_ref_keys;
sub hv_store(\%$$) ;
sub legal_ref_keys;
sub num_buckets(\%) ;
sub used_buckets(\%) ;
}
package Hash::Util::FieldHash {
sub CLONE;
sub _active_fields;
sub _fieldhash($$) ;
sub _test_uvar_get;
sub _test_uvar_same;
sub _test_uvar_set;
sub id($) ;
sub id_2obj($) ;
sub register($@) ;
}
package I18N::Langinfo {
sub AUTOLOAD;
sub langinfo(_) ;
}
package IO::Compress::Adapter::Deflate {
sub DEF_WBITS;
sub OS_CODE;
sub ZLIBNG_VERNUM;
sub ZLIBNG_VERSION;
sub ZLIBNG_VER_MAJOR;
sub ZLIBNG_VER_MINOR;
sub ZLIBNG_VER_MODIFIED;
sub ZLIBNG_VER_REVISION;
sub ZLIBNG_VER_STATUS;
sub ZLIB_VERNUM;
sub ZLIB_VERSION;
sub Z_ASCII;
sub Z_BEST_COMPRESSION;
sub Z_BEST_SPEED;
sub Z_BINARY;
sub Z_BLOCK;
sub Z_BUF_ERROR;
sub Z_DATA_ERROR;
sub Z_ERRNO;
sub Z_FILTERED;
sub Z_FINISH;
sub Z_FIXED;
sub Z_FULL_FLUSH;
sub Z_HUFFMAN_ONLY;
sub Z_MEM_ERROR;
sub Z_NEED_DICT;
sub Z_NO_COMPRESSION;
sub Z_NO_FLUSH;
sub Z_NULL;
sub Z_OK;
sub Z_PARTIAL_FLUSH;
sub Z_RLE;
sub Z_STREAM_END;
sub Z_STREAM_ERROR;
sub Z_SYNC_FLUSH;
sub Z_TREES;
sub Z_UNKNOWN;
sub Z_VERSION_ERROR;
}
package IO::Compress::Base {
sub ckInOutParams;
}
package IO::Compress::Base::Common {
sub blessed($) ;
sub ckInOutParams;
sub readonly($) ;
}
package IO::Compress::Gzip {
sub OS_CODE;
sub ZLIBNG_VERNUM;
sub ZLIBNG_VERSION;
sub ZLIBNG_VER_MAJOR;
sub ZLIBNG_VER_MINOR;
sub ZLIBNG_VER_MODIFIED;
sub ZLIBNG_VER_REVISION;
sub ZLIBNG_VER_STATUS;
sub ZLIB_VERNUM;
sub ZLIB_VERSION;
sub Z_ASCII;
sub Z_BEST_COMPRESSION;
sub Z_BEST_SPEED;
sub Z_BINARY;
sub Z_BLOCK;
sub Z_BUF_ERROR;
sub Z_DATA_ERROR;
sub Z_ERRNO;
sub Z_FILTERED;
sub Z_FINISH;
sub Z_FIXED;
sub Z_FULL_FLUSH;
sub Z_HUFFMAN_ONLY;
sub Z_MEM_ERROR;
sub Z_NEED_DICT;
sub Z_NO_COMPRESSION;
sub Z_NO_FLUSH;
sub Z_NULL;
sub Z_OK;
sub Z_PARTIAL_FLUSH;
sub Z_RLE;
sub Z_STREAM_END;
sub Z_STREAM_ERROR;
sub Z_SYNC_FLUSH;
sub Z_TREES;
sub Z_UNKNOWN;
sub Z_VERSION_ERROR;
sub noUTF8;
}
package IO::Compress::RawDeflate {
sub OS_CODE;
sub ZLIBNG_VERNUM;
sub ZLIBNG_VERSION;
sub ZLIBNG_VER_MAJOR;
sub ZLIBNG_VER_MINOR;
sub ZLIBNG_VER_MODIFIED;
sub ZLIBNG_VER_REVISION;
sub ZLIBNG_VER_STATUS;
sub ZLIB_VERNUM;
sub ZLIB_VERSION;
sub Z_ASCII;
sub Z_BEST_COMPRESSION;
sub Z_BEST_SPEED;
sub Z_BINARY;
sub Z_BLOCK;
sub Z_BUF_ERROR;
sub Z_DATA_ERROR;
sub Z_ERRNO;
sub Z_FILTERED;
sub Z_FINISH;
sub Z_FIXED;
sub Z_FULL_FLUSH;
sub Z_HUFFMAN_ONLY;
sub Z_MEM_ERROR;
sub Z_NEED_DICT;
sub Z_NO_COMPRESSION;
sub Z_NO_FLUSH;
sub Z_NULL;
sub Z_OK;
sub Z_PARTIAL_FLUSH;
sub Z_RLE;
sub Z_STREAM_END;
sub Z_STREAM_ERROR;
sub Z_SYNC_FLUSH;
sub Z_TREES;
sub Z_UNKNOWN;
sub Z_VERSION_ERROR;
}
package IO::File {
sub O_ALIAS() ;
sub O_DEFER() ;
sub O_EXLOCK() ;
sub O_NOINHERIT() ;
sub O_RANDOM() ;
sub O_RAW() ;
sub O_RSRC() ;
sub O_SEQUENTIAL() ;
sub O_SHLOCK() ;
sub O_TEMPORARY() ;
sub new_tmpfile;
}
package IO::Handle {
sub blocking($;$) ;
sub clearerr;
sub error;
sub flush;
sub getline;
sub getlines;
sub gets;
sub setbuf;
sub setvbuf;
sub sync;
sub ungetc;
sub untaint;
}
package IO::Poll {
sub _poll;
}
package IO::Seekable {
sub getpos;
sub setpos;
}
package IO::Socket {
sub sockatmark($) ;
}
package IO::Uncompress::Adapter::Inflate {
sub Z_BUF_ERROR;
sub Z_FINISH;
sub Z_OK;
sub Z_STREAM_END;
}
package IO::Uncompress::Base {
sub O_ALIAS() ;
sub O_DEFER() ;
sub O_EXLOCK() ;
sub O_NOINHERIT() ;
sub O_RANDOM() ;
sub O_RAW() ;
sub O_RSRC() ;
sub O_SEQUENTIAL() ;
sub O_SHLOCK() ;
sub O_TEMPORARY() ;
sub ckInOutParams;
}
package IO::Uncompress::RawInflate {
sub DEF_WBITS;
sub OS_CODE;
sub ZLIBNG_VERNUM;
sub ZLIBNG_VERSION;
sub ZLIBNG_VER_MAJOR;
sub ZLIBNG_VER_MINOR;
sub ZLIBNG_VER_MODIFIED;
sub ZLIBNG_VER_REVISION;
sub ZLIBNG_VER_STATUS;
sub ZLIB_VERNUM;
sub ZLIB_VERSION;
sub Z_ASCII;
sub Z_BEST_COMPRESSION;
sub Z_BEST_SPEED;
sub Z_BINARY;
sub Z_BLOCK;
sub Z_BUF_ERROR;
sub Z_DATA_ERROR;
sub Z_ERRNO;
sub Z_FILTERED;
sub Z_FINISH;
sub Z_FIXED;
sub Z_FULL_FLUSH;
sub Z_HUFFMAN_ONLY;
sub Z_MEM_ERROR;
sub Z_NEED_DICT;
sub Z_NO_COMPRESSION;
sub Z_NO_FLUSH;
sub Z_NULL;
sub Z_OK;
sub Z_PARTIAL_FLUSH;
sub Z_RLE;
sub Z_STREAM_END;
sub Z_STREAM_ERROR;
sub Z_SYNC_FLUSH;
sub Z_TREES;
sub Z_UNKNOWN;
sub Z_VERSION_ERROR;
sub adler32;
sub crc32;
}
package IPC::Msg::stat {
sub pack($) ;
sub unpack($$) ;
}
package IPC::Semaphore::stat {
sub pack($) ;
sub unpack($$) ;
}
package IPC::SharedMem::stat {
sub pack($) ;
sub unpack($$) ;
}
package IPC::SysV {
sub _constant($) ;
sub ftok($;$) ;
sub memread($$$$) ;
sub memwrite($$$$) ;
sub shmat($$$) ;
sub shmdt($) ;
}
package Internals {
sub SvREADONLY(\[$%@];$) ;
sub SvREFCNT(\[$%@];$) ;
sub V;
sub hv_clear_placeholders(\%) ;
sub stack_refcounted;
}
package JSON {
sub decode_json($) ;
sub encode_json($) ;
}
package JSON::XS {
sub CLONE;
sub DESTROY;
sub allow_blessed;
sub allow_nonref;
sub allow_tags;
sub allow_unknown;
sub ascii;
sub boolean_values;
sub canonical;
sub convert_blessed;
sub decode;
sub decode_json($) ;
sub decode_prefix;
sub encode;
sub encode_json($) ;
sub filter_json_object;
sub filter_json_single_key_object;
sub get_allow_blessed;
sub get_allow_nonref;
sub get_allow_tags;
sub get_allow_unknown;
sub get_ascii;
sub get_boolean_values;
sub get_canonical;
sub get_convert_blessed;
sub get_indent;
sub get_latin1;
sub get_max_depth;
sub get_max_size;
sub get_relaxed;
sub get_shrink;
sub get_space_after;
sub get_space_before;
sub get_utf8;
sub incr_parse;
sub incr_reset;
sub incr_skip;
sub indent;
sub latin1;
sub max_depth;
sub max_size;
sub new;
sub pretty;
sub relaxed;
sub shrink;
sub space_after;
sub space_before;
sub utf8;
}
package List::SomeUtils::PP {
sub max(@) ;
}
package List::SomeUtils::XS {
sub _array_iterator(;$) ;
sub _natatime_iterator() ;
sub after(&@) ;
sub after_incl(&@) ;
sub all(&@) ;
sub all_u(&@) ;
sub any(&@) ;
sub any_u(&@) ;
sub apply(&@) ;
sub before(&@) ;
sub before_incl(&@) ;
sub bsearch(&@) ;
sub bsearchidx(&@) ;
sub each_array(\@;\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@) ;
sub each_arrayref;
sub false(&@) ;
sub firstidx(&@) ;
sub firstres(&@) ;
sub firstval(&@) ;
sub indexes(&@) ;
sub insert_after(&$\@) ;
sub insert_after_string($$\@) ;
sub lastidx(&@) ;
sub lastres(&@) ;
sub lastval(&@) ;
sub mesh(\@\@;\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@\@) ;
sub minmax(@) ;
sub mode(@) ;
sub natatime($@) ;
sub none(&@) ;
sub none_u(&@) ;
sub notall(&@) ;
sub notall_u(&@) ;
sub one(&@) ;
sub one_u(&@) ;
sub onlyidx(&@) ;
sub onlyres(&@) ;
sub onlyval(&@) ;
sub pairwise(&\@\@) ;
sub part(&@) ;
sub singleton(@) ;
sub true(&@) ;
sub uniq(@) ;
}
package List::SomeUtils_ea {
sub DESTROY;
}
package List::SomeUtils_na {
sub DESTROY;
}
package List::Util {
sub all(&@) ;
sub any(&@) ;
sub first(&@) ;
sub head($@) ;
sub max(@) ;
sub maxstr(@) ;
sub mesh;
sub mesh_longest;
sub mesh_shortest;
sub min(@) ;
sub minstr(@) ;
sub none(&@) ;
sub notall(&@) ;
sub pairfirst(&@) ;
sub pairgrep(&@) ;
sub pairkeys(@) ;
sub pairmap(&@) ;
sub pairs(@) ;
sub pairvalues(@) ;
sub product(@) ;
sub reduce(&@) ;
sub reductions(&@) ;
sub sample($@) ;
sub shuffle(@) ;
sub sum(@) ;
sub sum0(@) ;
sub tail($@) ;
sub uniq(@) ;
sub uniqint(@) ;
sub uniqnum(@) ;
sub uniqstr(@) ;
sub unpairs(@) ;
sub zip;
sub zip_longest;
sub zip_shortest;
}
package MIME::Base64 {
sub decode($) ;
sub decode_base64($) ;
sub decoded_base64_length($) ;
sub encode($;$) ;
sub encode_base64($;$) ;
sub encoded_base64_length($;$) ;
}
package MIME::QuotedPrint {
sub decode_qp($) ;
sub encode_qp($;$$) ;
}
package Math::BigInt::FastCalc {
sub __strip_zeros;
sub _acmp;
sub _copy;
sub _dec;
sub _inc;
sub _is_even;
sub _is_odd;
sub _is_one;
sub _is_ten;
sub _is_two;
sub _is_zero;
sub _len;
sub _new;
sub _one;
sub _ten;
sub _two;
sub _zero;
}
package Math::BigInt::LTM {
sub DESTROY;
sub STORABLE_freeze;
sub STORABLE_thaw;
sub _1ex;
sub _acmp;
sub _add;
sub _alen;
sub _and;
sub _as_bytes;
sub _copy;
sub _dec;
sub _div;
sub _from_base;
sub _from_bin;
sub _from_bytes;
sub _from_hex;
sub _from_oct;
sub _gcd;
sub _inc;
sub _is_even;
sub _is_odd;
sub _is_one;
sub _is_ten;
sub _is_two;
sub _is_zero;
sub _lcm;
sub _len;
sub _lsft;
sub _mod;
sub _modinv;
sub _modpow;
sub _mul;
sub _new;
sub _one;
sub _or;
sub _pow;
sub _root;
sub _rsft;
sub _set;
sub _sqrt;
sub _str;
sub _sub;
sub _ten;
sub _to_base;
sub _to_bin;
sub _to_bytes;
sub _to_hex;
sub _to_oct;
sub _two;
sub _xor;
sub _zero;
sub _zeros;
}
package Mojo::BaseUtil {
sub set_subname;
}
package Mojo::Collection {
sub blessed($) ;
sub is_regexp($) ;
}
package Mojo::Collection::XS {
sub each_fast;
sub grep_fast;
sub map_fast;
sub map_ultra;
sub while_fast;
sub while_ultra;
}
package Mojo::Util {
sub b64_decode($) ;
sub b64_encode($;$) ;
sub decode_base64($) ;
sub encode_base64($;$) ;
sub hmac_sha1_hex(;@) ;
sub hmac_sha1_sum(;@) ;
sub inet_pton;
sub md5;
sub md5_bytes;
sub md5_hex;
sub md5_sum;
sub min(@) ;
sub sha1(;@) ;
sub sha1_bytes(;@) ;
sub sha1_hex(;@) ;
sub sha1_sum(;@) ;
}
package Moose {
sub is_class_loaded;
}
package Moose::Exporter {
sub _export_is_flagged;
sub _flag_as_reexport;
sub is_class_loaded;
sub reftype($) ;
sub set_subname;
sub uniq(@) ;
}
package Moose::Meta::Attribute {
sub any(&@) ;
sub blessed($) ;
}
package Moose::Meta::Class {
sub any(&@) ;
sub blessed($) ;
}
package Moose::Meta::Class::Immutable::Trait {
sub blessed($) ;
}
package Moose::Meta::Method::Constructor {
sub weaken($) ;
}
package Moose::Meta::Method::Delegation {
sub blessed($) ;
sub weaken($) ;
}
package Moose::Meta::Method::Destructor {
sub blessed($) ;
sub weaken($) ;
}
package Moose::Meta::Object::Trait {
sub blessed($) ;
}
package Moose::Meta::Role {
sub blessed($) ;
}
package Moose::Meta::Role::Application {
sub all(&@) ;
}
package Moose::Meta::Role::Application::RoleSummation {
sub all(&@) ;
sub blessed($) ;
}
package Moose::Meta::Role::Application::ToClass {
sub first(&@) ;
sub weaken($) ;
}
package Moose::Meta::Role::Application::ToInstance {
sub _reset_amagic;
sub all(&@) ;
sub blessed($) ;
}
package Moose::Meta::Role::Attribute {
sub all(&@) ;
sub blessed($) ;
sub weaken($) ;
}
package Moose::Meta::Role::Composite {
sub blessed($) ;
}
package Moose::Meta::TypeCoercion::Union {
sub blessed($) ;
}
package Moose::Meta::TypeConstraint {
sub refaddr($) ;
sub set_subname;
}
package Moose::Meta::TypeConstraint::DuckType {
sub all(&@) ;
sub blessed($) ;
}
package Moose::Meta::TypeConstraint::Parameterized {
sub blessed($) ;
}
package Moose::Meta::TypeConstraint::Registry {
sub blessed($) ;
}
package Moose::Meta::TypeConstraint::Union {
sub all(&@) ;
sub first(&@) ;
}
package Moose::Util {
sub all(&@) ;
sub any(&@) ;
sub blessed($) ;
sub first(&@) ;
}
package Moose::Util::MetaRole {
sub all(&@) ;
sub blessed($) ;
sub first(&@) ;
}
package Moose::Util::TypeConstraints {
sub blessed($) ;
}
package Moose::Util::TypeConstraints::Builtins {
sub _RegexpRef;
sub blessed($) ;
sub is_class_loaded;
}
package Net::DNS::Native {
sub DESTROY;
sub _get_result;
sub _getaddrinfo;
sub _is_non_safe_symbols_loaded;
sub _timedout;
sub new;
sub pack_sockaddr_in6;
sub unpack_sockaddr_in6;
}
package Net::SSLeay {
sub AF_802() ;
sub AF_AAL() ;
sub AF_CCITT() ;
sub AF_CHAOS() ;
sub AF_CTF() ;
sub AF_DATAKIT() ;
sub AF_DLI() ;
sub AF_ECMA() ;
sub AF_GOSIP() ;
sub AF_HYLINK() ;
sub AF_IMPLINK() ;
sub AF_ISO() ;
sub AF_LAST() ;
sub AF_LAT() ;
sub AF_LINK() ;
sub AF_NBS() ;
sub AF_NIT() ;
sub AF_NS() ;
sub AF_OSI() ;
sub AF_OSINET() ;
sub AF_PUP() ;
sub AF_USER() ;
sub AF_WAN() ;
sub MSG_BCAST() ;
sub MSG_BTAG() ;
sub MSG_CTLFLAGS() ;
sub MSG_CTLIGNORE() ;
sub MSG_EOF() ;
sub MSG_ETAG() ;
sub MSG_MAXIOVLEN() ;
sub MSG_MCAST() ;
sub MSG_URG() ;
sub MSG_WIRE() ;
sub PF_802() ;
sub PF_AAL() ;
sub PF_CCITT() ;
sub PF_CHAOS() ;
sub PF_CTF() ;
sub PF_DATAKIT() ;
sub PF_DLI() ;
sub PF_ECMA() ;
sub PF_GOSIP() ;
sub PF_HYLINK() ;
sub PF_IMPLINK() ;
sub PF_ISO() ;
sub PF_LAST() ;
sub PF_LAT() ;
sub PF_LINK() ;
sub PF_NBS() ;
sub PF_NIT() ;
sub PF_NS() ;
sub PF_OSI() ;
sub PF_OSINET() ;
sub PF_PUP() ;
sub PF_USER() ;
sub PF_WAN() ;
sub SCM_CONNECT() ;
sub SCM_CREDS() ;
sub SO_BACKLOG() ;
sub SO_CHAMELEON() ;
sub SO_DGRAM_ERRIND() ;
sub SO_DONTLINGER() ;
sub SO_FAMILY() ;
sub SO_PASSIFNAME() ;
sub SO_PROTOTYPE() ;
sub SO_STATE() ;
sub SO_USELOOPBACK() ;
sub SO_XOPEN() ;
sub SO_XSE() ;
sub debug_read;
sub do_https2;
sub do_https3;
sub do_https4;
sub do_https;
sub do_httpx2;
sub do_httpx3;
sub do_httpx4;
sub dump_peer_certificate($) ;
sub get_http3;
sub get_http4;
sub get_http;
sub get_https3;
sub get_https4;
sub get_https;
sub get_httpx3;
sub get_httpx4;
sub get_httpx;
sub head_http3;
sub head_http4;
sub head_http;
sub head_https3;
sub head_https4;
sub head_https;
sub head_httpx3;
sub head_httpx4;
sub head_httpx;
sub http_cat;
sub https_cat;
sub httpx_cat;
sub inet_aton;
sub inet_ntoa;
sub initialize;
sub make_form;
sub make_headers;
sub new_x_ctx;
sub open_proxy_tcp_connection;
sub open_tcp_connection;
sub pack_sockaddr_in6;
sub pack_sockaddr_in;
sub pack_sockaddr_un;
sub post_http3;
sub post_http4;
sub post_http;
sub post_https3;
sub post_https4;
sub post_https;
sub post_httpx3;
sub post_httpx4;
sub post_httpx;
sub put_http3;
sub put_http4;
sub put_http;
sub put_https3;
sub put_https4;
sub put_https;
sub put_httpx3;
sub put_httpx4;
sub put_httpx;
sub randomize(;$$$) ;
sub set_cert_and_key($$$) ;
sub set_proxy($$;**) ;
sub set_server_cert_and_key($$$) ;
sub sockaddr_family;
sub ssl_read_CRLF($;$) ;
sub ssl_read_all;
sub ssl_read_until($;$$) ;
sub ssl_write_CRLF($$) ;
sub ssl_write_all;
sub sslcat;
sub tcp_read_CRLF;
sub tcp_read_all;
sub tcp_read_until;
sub tcp_write_CRLF;
sub tcp_write_all;
sub tcpcat;
sub tcpxcat;
sub unpack_sockaddr_in6;
sub unpack_sockaddr_in;
sub unpack_sockaddr_un;
sub want_X509_lookup;
sub want_nothing;
sub want_read;
sub want_write;
}
package Opcode {
sub _safe_call_sv($$$) ;
sub _safe_pkg_prep($) ;
sub define_optag($$) ;
sub deny($;@) ;
sub deny_only($;@) ;
sub empty_opset() ;
sub full_opset() ;
sub invert_opset($) ;
sub opcodes() ;
sub opdesc(;@) ;
sub opmask() ;
sub opmask_add($) ;
sub opset(;@) ;
sub opset_to_ops($;$) ;
sub permit($;@) ;
sub permit_only($;@) ;
sub verify_opset($;$) ;
}
package POSIX {
sub ARG_MAX() ;
sub CHILD_MAX() ;
sub CLK_TCK() ;
sub EOTHER() ;
sub EPROCLIM() ;
sub FLT_ROUNDS() ;
sub LDBL_EPSILON() ;
sub LDBL_MAX() ;
sub LDBL_MIN() ;
sub LINK_MAX() ;
sub L_tmpnam;
sub OPEN_MAX() ;
sub STREAM_MAX() ;
sub S_ISBLK;
sub S_ISCHR;
sub S_ISDIR;
sub S_ISFIFO;
sub S_ISLNK;
sub S_ISREG;
sub S_ISSOCK;
sub TZNAME_MAX() ;
sub WEXITSTATUS;
sub WIFEXITED;
sub WIFSIGNALED;
sub WIFSTOPPED;
sub WSTOPSIG;
sub WTERMSIG;
sub _exit;
sub abort;
sub abs;
sub access;
sub acos;
sub acosh;
sub alarm;
sub asctime;
sub asin;
sub asinh;
sub assert;
sub atan2;
sub atan;
sub atanh;
sub atexit;
sub atof;
sub atoi;
sub atol;
sub bsearch;
sub calloc;
sub cbrt;
sub ceil;
sub chdir;
sub chmod;
sub chown;
sub clearerr;
sub clock;
sub close;
sub closedir;
sub constant;
sub copysign;
sub cos;
sub cosh;
sub creat;
sub ctermid;
sub ctime;
sub cuserid;
sub difftime;
sub div;
sub dup2;
sub dup;
sub erf;
sub erfc;
sub errno;
sub execl;
sub execle;
sub execlp;
sub execv;
sub execve;
sub execvp;
sub exit;
sub exp2;
sub exp;
sub expm1;
sub fabs;
sub fclose;
sub fcntl;
sub fdim;
sub fdopen;
sub fegetround() ;
sub feof;
sub ferror;
sub fesetround;
sub fflush;
sub fgetc;
sub fgetpos;
sub fgets;
sub fileno;
sub floor;
sub fma;
sub fmax;
sub fmin;
sub fmod;
sub fopen;
sub fork;
sub fpathconf;
sub fpclassify;
sub fprintf;
sub fputc;
sub fputs;
sub fread;
sub free;
sub freopen;
sub frexp;
sub fscanf;
sub fseek;
sub fsetpos;
sub fstat;
sub fsync;
sub ftell;
sub fwrite;
sub getc;
sub getchar;
sub getcwd;
sub getegid;
sub getenv;
sub geteuid;
sub getgid;
sub getgrgid;
sub getgrnam;
sub getgroups;
sub getlogin;
sub getpayload;
sub getpgrp;
sub getpid;
sub getppid;
sub getpwnam;
sub getpwuid;
sub gets;
sub getuid;
sub gmtime;
sub hypot;
sub ilogb;
sub isatty;
sub isfinite;
sub isgreater;
sub isgreaterequal;
sub isinf;
sub isless;
sub islessequal;
sub islessgreater;
sub isnan;
sub isnormal;
sub issignaling;
sub isunordered;
sub j0;
sub j1;
sub jn;
sub kill;
sub labs;
sub lchown;
sub ldexp;
sub ldiv;
sub lgamma;
sub link;
sub localeconv;
sub localtime;
sub log10;
sub log1p;
sub log2;
sub log;
sub logb;
sub longjmp;
sub lrint;
sub lround;
sub lseek;
sub malloc;
sub mblen;
sub mbtowc;
sub memchr;
sub memcmp;
sub memcpy;
sub memmove;
sub memset;
sub mkdir;
sub mkfifo;
sub mktime;
sub modf;
sub nan;
sub nearbyint;
sub nextafter;
sub nexttoward;
sub nice;
sub offsetof;
sub open;
sub opendir;
sub pathconf;
sub pause;
sub pipe;
sub pow;
sub putc;
sub putchar;
sub puts;
sub qsort;
sub raise;
sub rand;
sub read;
sub readdir;
sub realloc;
sub remainder;
sub remove;
sub remquo;
sub rename;
sub rewind;
sub rewinddir;
sub rint;
sub rmdir;
sub round;
sub scalbn;
sub scanf;
sub setbuf;
sub setgid;
sub setjmp;
sub setlocale;
sub setpayload;
sub setpayloadsig;
sub setpgid;
sub setsid;
sub setuid;
sub setvbuf;
sub sigaction;
sub siglongjmp;
sub signbit;
sub sigpending;
sub sigprocmask;
sub sigsetjmp;
sub sigsuspend;
sub sin;
sub sinh;
sub sleep;
sub sqrt;
sub srand;
sub sscanf;
sub stat;
sub strcat;
sub strchr;
sub strcmp;
sub strcoll;
sub strcpy;
sub strcspn;
sub strerror;
sub strftime;
sub strlen;
sub strncat;
sub strncmp;
sub strncpy;
sub strpbrk;
sub strrchr;
sub strspn;
sub strstr;
sub strtod;
sub strtok;
sub strtol;
sub strtold;
sub strtoul;
sub strxfrm;
sub sysconf;
sub system;
sub tan;
sub tanh;
sub tcdrain;
sub tcflow;
sub tcflush;
sub tcgetpgrp;
sub tcsendbreak;
sub tcsetpgrp;
sub tgamma;
sub time;
sub times;
sub tmpfile;
sub tmpnam;
sub trunc;
sub ttyname;
sub tzname;
sub tzset;
sub umask;
sub uname;
sub ungetc;
sub unlink;
sub utime;
sub vfprintf;
sub vprintf;
sub vsprintf;
sub wait;
sub waitpid;
sub wctomb;
sub write;
sub y0;
sub y1;
sub yn;
}
package POSIX::SigSet {
sub addset;
sub delset;
sub emptyset;
sub fillset;
sub ismember;
sub new;
}
package POSIX::Termios {
sub getattr;
sub getcc;
sub getcflag;
sub getiflag;
sub getispeed;
sub getlflag;
sub getoflag;
sub getospeed;
sub new;
sub setattr;
sub setcc;
sub setcflag;
sub setiflag;
sub setispeed;
sub setlflag;
sub setoflag;
sub setospeed;
}
package Package::DeprecationManager {
sub _HASH0($) ;
sub any(&@) ;
sub set_subname;
}
package Package::Stash {
sub add_symbol;
sub get_all_symbols;
sub get_or_add_symbol;
sub get_symbol;
sub has_symbol;
sub list_all_symbols;
sub name;
sub namespace;
sub new;
sub remove_glob;
sub remove_symbol;
}
package Package::Stash::XS {
sub add_symbol;
sub get_all_symbols;
sub get_or_add_symbol;
sub get_symbol;
sub has_symbol;
sub list_all_symbols;
sub name;
sub namespace;
sub new;
sub remove_glob;
sub remove_symbol;
}
package PadWalker {
sub _upcontext;
sub closed_over;
sub peek_my;
sub peek_our;
sub peek_sub;
sub set_closed_over;
sub var_name;
}
package Params::Util {
sub _ARRAY($) ;
sub _ARRAY0($) ;
sub _ARRAYLIKE($) ;
sub _CODE($) ;
sub _CODELIKE($) ;
sub _HASH($) ;
sub _HASH0($) ;
sub _HASHLIKE($) ;
sub _INSTANCE($$) ;
sub _NUMBER($) ;
sub _REGEX($) ;
sub _SCALAR($) ;
sub _SCALAR0($) ;
sub _STRING($) ;
sub _XScompiled;
}
package Params::Util::PP {
sub looks_like_number($) ;
}
package Params::Validate::XS {
sub validate(\@$) ;
sub validate_pos(\@@) ;
sub validate_with;
}
package Params::ValidationCompiler::Compiler {
sub blessed($) ;
sub looks_like_number($) ;
sub pairkeys(@) ;
sub pairvalues(@) ;
sub perlstring;
sub reftype($) ;
sub set_subname;
}
package PerlIO {
sub get_layers(*;@) ;
}
package PerlIO::Layer {
sub NoWarnings;
sub find;
}
package Pod::Text {
sub encode($$;$) ;
}
package Proc::ProcessTable {
sub _initialize_os;
sub constant;
sub fields;
sub mutex_new;
sub mutex_table;
sub table;
}
package Regexp {
sub DESTROY() ;
}
package Role::Tiny {
sub _linear_isa($;$) ;
}
package SDBM_File {
sub DELETE;
sub DESTROY;
sub EXISTS;
sub FETCH;
sub FIRSTKEY;
sub NEXTKEY;
sub STORE;
sub TIEHASH;
sub error;
sub filter_fetch_key;
sub filter_fetch_value;
sub filter_store_key;
sub filter_store_value;
sub sdbm_clearerr;
}
package Scalar::Util {
sub blessed($) ;
sub dualvar($$) ;
sub isdual($) ;
sub isvstring($) ;
sub isweak($) ;
sub looks_like_number($) ;
sub openhandle($) ;
sub readonly($) ;
sub refaddr($) ;
sub reftype($) ;
sub tainted($) ;
sub unweaken($) ;
sub weaken($) ;
}
package Sereal::Decoder {
sub DESTROY;
sub bytes_consumed;
sub decode($$;$) ;
sub decode_only_header($$;$) ;
sub decode_only_header_with_offset($$$;$) ;
sub decode_sereal;
sub decode_sereal_with_header_data;
sub decode_with_header($$;$$) ;
sub decode_with_header_and_offset($$$;$$) ;
sub decode_with_offset($$$;$) ;
sub flags;
sub looks_like_sereal;
sub new;
sub regexp_internals_type;
sub scalar_looks_like_sereal($) ;
sub sereal_decode_only_header_with_object($$;$) ;
sub sereal_decode_only_header_with_offset_with_object($$$;$) ;
sub sereal_decode_with_header_and_offset_with_object($$$;$$) ;
sub sereal_decode_with_header_with_object($$;$$) ;
sub sereal_decode_with_object($$;$) ;
sub sereal_decode_with_offset_with_object($$$;$) ;
}
package Sereal::Encoder {
sub DESTROY;
sub encode($$;$) ;
sub encode_sereal;
sub encode_sereal_with_header_data;
sub flags;
sub new;
sub sereal_encode_with_object($$;$) ;
}
package Sereal::Encoder::_ptabletest {
sub test;
}
package Socket {
sub AF_802() ;
sub AF_AAL() ;
sub AF_CCITT() ;
sub AF_CHAOS() ;
sub AF_CTF() ;
sub AF_DATAKIT() ;
sub AF_DLI() ;
sub AF_ECMA() ;
sub AF_GOSIP() ;
sub AF_HYLINK() ;
sub AF_IMPLINK() ;
sub AF_ISO() ;
sub AF_LAST() ;
sub AF_LAT() ;
sub AF_LINK() ;
sub AF_NBS() ;
sub AF_NIT() ;
sub AF_NS() ;
sub AF_OSI() ;
sub AF_OSINET() ;
sub AF_PUP() ;
sub AF_USER() ;
sub AF_WAN() ;
sub AUTOLOAD;
sub EAI_BADHINTS() ;
sub EAI_PROTOCOL() ;
sub IPTOS_LOWDELAY() ;
sub IPTOS_MINCOST() ;
sub IPTOS_RELIABILITY() ;
sub IPTOS_THROUGHPUT() ;
sub IPV6_ADDRFROM() ;
sub LOCAL_CONNWAIT() ;
sub LOCAL_CREDS() ;
sub LOCAL_OCREDS() ;
sub LOCAL_PEEREID() ;
sub MSG_BCAST() ;
sub MSG_BTAG() ;
sub MSG_CTLFLAGS() ;
sub MSG_CTLIGNORE() ;
sub MSG_EOF() ;
sub MSG_ETAG() ;
sub MSG_MAXIOVLEN() ;
sub MSG_MCAST() ;
sub MSG_URG() ;
sub MSG_WIRE() ;
sub PF_802() ;
sub PF_AAL() ;
sub PF_CCITT() ;
sub PF_CHAOS() ;
sub PF_CTF() ;
sub PF_DATAKIT() ;
sub PF_DLI() ;
sub PF_ECMA() ;
sub PF_GOSIP() ;
sub PF_HYLINK() ;
sub PF_IMPLINK() ;
sub PF_ISO() ;
sub PF_LAST() ;
sub PF_LAT() ;
sub PF_LINK() ;
sub PF_NBS() ;
sub PF_NIT() ;
sub PF_NS() ;
sub PF_OSI() ;
sub PF_OSINET() ;
sub PF_PUP() ;
sub PF_USER() ;
sub PF_WAN() ;
sub SCM_CONNECT() ;
sub SCM_CREDS() ;
sub SO_BACKLOG() ;
sub SO_CHAMELEON() ;
sub SO_DGRAM_ERRIND() ;
sub SO_DONTLINGER() ;
sub SO_FAMILY() ;
sub SO_PASSIFNAME() ;
sub SO_PROTOTYPE() ;
sub SO_STATE() ;
sub SO_USELOOPBACK() ;
sub SO_XOPEN() ;
sub SO_XSE() ;
sub TCP_CONNECTIONTIMEOUT() ;
sub TCP_INIT_CWND() ;
sub TCP_KEEPALIVE() ;
sub TCP_MAXRT() ;
sub TCP_NOOPT() ;
sub TCP_NOPUSH() ;
sub TCP_SACK_ENABLE() ;
sub TCP_STDURG() ;
sub getaddrinfo;
sub getnameinfo;
sub inet_aton;
sub inet_ntoa;
sub inet_ntop;
sub inet_pton;
sub pack_ip_mreq;
sub pack_ip_mreq_source;
sub pack_ipv6_mreq;
sub pack_sockaddr_in6;
sub pack_sockaddr_in;
sub pack_sockaddr_un;
sub sockaddr_family;
sub unpack_ip_mreq;
sub unpack_ip_mreq_source;
sub unpack_ipv6_mreq;
sub unpack_sockaddr_in6;
sub unpack_sockaddr_in;
sub unpack_sockaddr_un;
}
package Specio::Constraint::AnyCan {
sub perlstring;
}
package Specio::Constraint::Enum {
sub refaddr($) ;
}
package Specio::Constraint::ObjectCan {
sub perlstring;
}
package Specio::Constraint::ObjectIsa {
sub perlstring;
}
package Specio::Constraint::Role::CanType {
sub blessed($) ;
}
package Specio::Constraint::Role::Interface {
sub all(&@) ;
sub any(&@) ;
sub first(&@) ;
}
package Specio::Constraint::Role::IsaType {
sub blessed($) ;
}
package Specio::Constraint::Union {
sub all(&@) ;
sub any(&@) ;
}
package Specio::Exception {
sub blessed($) ;
}
package Specio::Helpers {
sub blessed($) ;
sub perlstring;
}
package Specio::OO {
sub all(&@) ;
sub perlstring;
sub weaken($) ;
}
package Specio::PartialDump {
sub blessed($) ;
sub looks_like_number($) ;
sub reftype($) ;
}
package Specio::TypeChecks {
sub blessed($) ;
}
package Specio::XS {
sub clone($;$) ;
}
package Storable {
sub dclone($) ;
sub init_perinterp() ;
sub is_retrieving() ;
sub is_storing() ;
sub last_op_in_netorder() ;
sub mretrieve($;$) ;
sub mstore($) ;
sub net_mstore($) ;
sub net_pstore($$) ;
sub pretrieve($;$) ;
sub pstore($$) ;
sub stack_depth() ;
sub stack_depth_hash() ;
}
package Sub::Util {
sub set_prototype;
sub set_subname;
sub subname;
}
package Sys::Hostname {
sub ghname;
}
package Sys::Syslog {
sub AF_802() ;
sub AF_AAL() ;
sub AF_CCITT() ;
sub AF_CHAOS() ;
sub AF_CTF() ;
sub AF_DATAKIT() ;
sub AF_DLI() ;
sub AF_ECMA() ;
sub AF_GOSIP() ;
sub AF_HYLINK() ;
sub AF_IMPLINK() ;
sub AF_ISO() ;
sub AF_LAST() ;
sub AF_LAT() ;
sub AF_LINK() ;
sub AF_NBS() ;
sub AF_NIT() ;
sub AF_NS() ;
sub AF_OSI() ;
sub AF_OSINET() ;
sub AF_PUP() ;
sub AF_USER() ;
sub AF_WAN() ;
sub EAI_BADHINTS() ;
sub EAI_PROTOCOL() ;
sub IPTOS_LOWDELAY() ;
sub IPTOS_MINCOST() ;
sub IPTOS_RELIABILITY() ;
sub IPTOS_THROUGHPUT() ;
sub IPV6_ADDRFROM() ;
sub LOG_FAC;
sub LOG_MAKEPRI;
sub LOG_MASK;
sub LOG_PRI;
sub LOG_UPTO;
sub MSG_BCAST() ;
sub MSG_BTAG() ;
sub MSG_CTLFLAGS() ;
sub MSG_CTLIGNORE() ;
sub MSG_EOF() ;
sub MSG_ETAG() ;
sub MSG_MAXIOVLEN() ;
sub MSG_MCAST() ;
sub MSG_URG() ;
sub MSG_WIRE() ;
sub PF_802() ;
sub PF_AAL() ;
sub PF_CCITT() ;
sub PF_CHAOS() ;
sub PF_CTF() ;
sub PF_DATAKIT() ;
sub PF_DLI() ;
sub PF_ECMA() ;
sub PF_GOSIP() ;
sub PF_HYLINK() ;
sub PF_IMPLINK() ;
sub PF_ISO() ;
sub PF_LAST() ;
sub PF_LAT() ;
sub PF_LINK() ;
sub PF_NBS() ;
sub PF_NIT() ;
sub PF_NS() ;
sub PF_OSI() ;
sub PF_OSINET() ;
sub PF_PUP() ;
sub PF_USER() ;
sub PF_WAN() ;
sub SCM_CONNECT() ;
sub SCM_CREDS() ;
sub SO_BACKLOG() ;
sub SO_CHAMELEON() ;
sub SO_DGRAM_ERRIND() ;
sub SO_DONTLINGER() ;
sub SO_FAMILY() ;
sub SO_PASSIFNAME() ;
sub SO_PROTOTYPE() ;
sub SO_STATE() ;
sub SO_USELOOPBACK() ;
sub SO_XOPEN() ;
sub SO_XSE() ;
sub TCP_CONNECTIONTIMEOUT() ;
sub TCP_INIT_CWND() ;
sub TCP_KEEPALIVE() ;
sub TCP_MAXRT() ;
sub TCP_NOOPT() ;
sub TCP_NOPUSH() ;
sub TCP_SACK_ENABLE() ;
sub TCP_STDURG() ;
sub closelog_xs;
sub constant;
sub getaddrinfo;
sub getnameinfo;
sub inet_aton;
sub inet_ntoa;
sub inet_ntop;
sub inet_pton;
sub openlog_xs;
sub pack_ip_mreq;
sub pack_ip_mreq_source;
sub pack_ipv6_mreq;
sub pack_sockaddr_in6;
sub pack_sockaddr_in;
sub pack_sockaddr_un;
sub setlocale;
sub setlogmask_xs;
sub sockaddr_family;
sub strftime;
sub syslog_xs;
sub unpack_ip_mreq;
sub unpack_ip_mreq_source;
sub unpack_ipv6_mreq;
sub unpack_sockaddr_in6;
sub unpack_sockaddr_in;
sub unpack_sockaddr_un;
}
package Term::ReadKey {
sub GetControlChars;
sub GetSpeed;
sub GetTermSizeGSIZE;
sub GetTermSizeGWINSZ;
sub GetTermSizeVIO;
sub GetTermSizeWin32;
sub SetControlChars;
sub SetReadMode;
sub SetTerminalSize;
sub Win32PeekChar;
sub blockoptions;
sub pollfile;
sub selectfile;
sub setnodelay;
sub termoptions;
sub termsizeoptions;
}
package Test2::API {
sub blessed($) ;
sub time() ;
sub weaken($) ;
}
package Test2::API::Context {
sub blessed($) ;
sub weaken($) ;
}
package Test2::API::Instance {
sub reftype($) ;
}
package Test2::Event {
sub blessed($) ;
sub reftype($) ;
}
package Test2::Event::V2 {
sub reftype($) ;
}
package Test2::EventFacet::Trace {
sub time() ;
}
package Test2::Hub {
sub first(&@) ;
sub weaken($) ;
}
package Test2::Util::Facets2Legacy {
sub blessed($) ;
}
package Test2::Util::HashBase {
sub _isa($;$) ;
}
package Test::Builder {
sub blessed($) ;
sub reftype($) ;
sub weaken($) ;
}
package Test::LeakTrace {
sub CLONE;
sub _finish;
sub _runops_installed;
sub _start;
sub count_sv;
}
package Tie::Hash::NamedCapture {
sub CLEAR;
sub DELETE;
sub EXISTS;
sub FETCH;
sub FIRSTKEY;
sub NEXTKEY;
sub SCALAR;
sub STORE;
sub TIEHASH;
sub _tie_it;
sub flags;
}
package Time::HiRes {
sub alarm($;$) ;
sub clock() ;
sub clock_getres(;$) ;
sub clock_gettime(;$) ;
sub clock_nanosleep($$;$) ;
sub constant($) ;
sub getitimer($) ;
sub gettimeofday() ;
sub lstat(;$) ;
sub nanosleep($) ;
sub setitimer($$;$) ;
sub sleep(;@) ;
sub stat(;$) ;
sub time() ;
sub ualarm($;$) ;
sub usleep($) ;
sub utime($$@) ;
}
package Time::Piece {
sub _crt_gmtime($) ;
sub _crt_localtime($) ;
sub _get_localization() ;
sub _mini_mktime($$$$$$) ;
sub _strftime($$;$) ;
sub _strptime($$$$) ;
sub _tzset() ;
sub blessed($) ;
}
package Try::Tiny {
sub _subname;
}
package UNIVERSAL {
sub DOES;
sub VERSION;
sub can;
sub import;
sub isa;
sub unimport;
}
package Unicode::Collate {
sub _decompHangul;
sub _derivCE_14;
sub _derivCE_18;
sub _derivCE_20;
sub _derivCE_22;
sub _derivCE_24;
sub _derivCE_32;
sub _derivCE_34;
sub _derivCE_36;
sub _derivCE_38;
sub _derivCE_40;
sub _derivCE_43;
sub _derivCE_8;
sub _derivCE_9;
sub _exists_simple;
sub _fetch_rest;
sub _fetch_simple;
sub _getHexArray;
sub _ignorable_simple;
sub _isIllegal;
sub _isUIdeo;
sub _uideoCE_8;
sub getHST;
sub mk_SortKey;
sub varCE;
sub visualizeSortKey;
}
package Unicode::Normalize {
sub FCC($) ;
sub NFC($) ;
sub NFD($) ;
sub NFKC($) ;
sub NFKD($) ;
sub checkFCC($) ;
sub checkFCD($) ;
sub checkNFC($) ;
sub checkNFD($) ;
sub checkNFKC($) ;
sub checkNFKD($) ;
sub compose($) ;
sub composeContiguous($) ;
sub decompose($;$) ;
sub getCanon($) ;
sub getCombinClass($) ;
sub getCompat($) ;
sub getComposite($$) ;
sub isComp2nd($) ;
sub isComp_Ex($) ;
sub isExclusion($) ;
sub isNFC_MAYBE($) ;
sub isNFC_NO($) ;
sub isNFD_NO($) ;
sub isNFKC_MAYBE($) ;
sub isNFKC_NO($) ;
sub isNFKD_NO($) ;
sub isNonStDecomp($) ;
sub isSingleton($) ;
sub reorder($) ;
sub splitOnLastStarter;
}
package Variable::Magic {
sub CLONE;
sub _wizard;
sub cast(\[$@%&*]$@) ;
sub dispell(\[$@%&*]$) ;
sub getdata(\[$@%&*]$) ;
}
package XML::Parser::Expat {
sub DefaultCurrent;
sub Do_External_Parse;
sub ElementIndex;
sub ErrorString;
sub FreeEncoding;
sub GenerateNSName;
sub GetBase;
sub GetCurrentByteIndex;
sub GetCurrentColumnNumber;
sub GetCurrentLineNumber;
sub GetErrorCode;
sub GetSpecifiedAttributeCount;
sub LoadEncoding;
sub OriginalString;
sub ParseDone;
sub ParsePartial;
sub ParseStream;
sub ParseString;
sub ParserCreate;
sub ParserFree;
sub ParserRelease;
sub PositionContext;
sub RecognizedString;
sub SetAttListDeclHandler;
sub SetBase;
sub SetCharacterDataHandler;
sub SetCommentHandler;
sub SetDefaultHandler;
sub SetDoctypeHandler;
sub SetElementDeclHandler;
sub SetEndCdataHandler;
sub SetEndDoctypeHandler;
sub SetEndElementHandler;
sub SetEntityDeclHandler;
sub SetExtEntFinishHandler;
sub SetExternalEntityRefHandler;
sub SetNotationDeclHandler;
sub SetProcessingInstructionHandler;
sub SetStartCdataHandler;
sub SetStartElementHandler;
sub SetUnparsedEntityDeclHandler;
sub SetXMLDeclHandler;
sub SkipUntil;
sub UnsetAllHandlers;
}
package XS::Parse::Infix {
sub check_opname;
}
package XString {
sub cstring;
sub perlstring;
}
package YAML::XS {
sub DESTROY;
sub dump;
sub load;
sub new;
}
package YAML::XS::LibYAML {
sub Dump;
sub Load;
sub libyaml_version;
}
package attributes {
sub _fetch_attrs($) ;
sub _guess_stash($) ;
sub _modify_attrs;
sub reftype($) ;
}
package builtin {
sub blessed($) ;
sub ceil($) ;
sub created_as_number($) ;
sub created_as_string($) ;
sub export_lexically;
sub false() ;
sub floor($) ;
sub import;
sub indexed(@) ;
sub inf() ;
sub is_bool($) ;
sub is_tainted($) ;
sub is_weak($) ;
sub load_module($) ;
sub nan() ;
sub refaddr($) ;
sub reftype($) ;
sub stringify($) ;
sub trim($) ;
sub true() ;
sub unweaken($) ;
sub weaken($) ;
}
package constant {
sub _make_const(\[$@]) ;
}
package mro {
sub _nextcan;
sub get_isarev($) ;
sub get_linear_isa($;$) ;
sub get_mro($) ;
sub get_pkg_gen($) ;
sub invalidate_all_method_caches() ;
sub is_universal($) ;
sub method_changed_in($) ;
sub set_mro($$) ;
}
package re {
sub install;
sub is_regexp($) ;
sub optimization($) ;
sub regexp_pattern($) ;
sub regmust($) ;
sub regname(;$$) ;
sub regnames(;$) ;
sub regnames_count() ;
}
package threads {
sub DESTROY;
sub _handle;
sub create;
sub detach;
sub equal;
sub error;
sub get_stack_size;
sub is_detached;
sub is_joinable;
sub is_running;
sub join;
sub kill;
sub list;
sub new;
sub object;
sub self;
sub set_stack_size;
sub set_thread_exit_only;
sub tid;
sub wantarray;
sub yield;
}
package threads::shared {
sub _id(\[$@%]) ;
sub _refcnt(\[$@%]) ;
sub bless($;$) ;
sub blessed($) ;
sub cond_broadcast(\[$@%]) ;
sub cond_signal(\[$@%]) ;
sub cond_timedwait(\[$@%]$;\[$@%]) ;
sub cond_wait(\[$@%];\[$@%]) ;
sub is_shared(\[$@%]) ;
sub refaddr($) ;
sub reftype($) ;
sub share(\[$@%]) ;
}
package threads::shared::tie {
sub EXISTS;
sub EXTEND;
sub FIRSTKEY;
sub NEXTKEY;
sub POP;
sub PUSH;
sub SHIFT;
sub STORESIZE;
sub UNSHIFT;
}
package utf8 {
sub decode;
sub downgrade;
sub encode;
sub is_utf8;
sub native_to_unicode;
sub unicode_to_native;
sub upgrade;
sub valid;
}
package version {
sub _VERSION;
sub boolean;
sub declare;
sub is_alpha;
sub is_qv;
sub new;
sub noop;
sub normal;
sub numify;
sub parse;
sub qv;
sub stringify;
sub vcmp;
}
